
from __future__ import annotations
from typing import Optional
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .process_schedules_expression import (
    ProcessSchedulesExpression,
    ProcessSchedulesExpressionGuard,
)
from .process_schedules_simple_expression import ProcessSchedulesSimpleExpression
from .process_schedules_grouping_expression import ProcessSchedulesGroupingExpression


@JsonMap({})
class ProcessSchedulesQueryConfigQueryFilter(BaseModel):
    """ProcessSchedulesQueryConfigQueryFilter

    :param expression: expression
    :type expression: ProcessSchedulesExpression
    """

    def __init__(self, expression: ProcessSchedulesExpression, **kwargs):
        """ProcessSchedulesQueryConfigQueryFilter

        :param expression: expression
        :type expression: ProcessSchedulesExpression
        """
        self.expression = ProcessSchedulesExpressionGuard.return_one_of(expression)
        self._kwargs = kwargs


@JsonMap({"query_filter": "QueryFilter"})
class ProcessSchedulesQueryConfig(BaseModel):
    """ProcessSchedulesQueryConfig

    :param query_filter: query_filter (optional)
    :type query_filter: Optional[ProcessSchedulesQueryConfigQueryFilter]
    """

    def __init__(self, query_filter: Optional[ProcessSchedulesQueryConfigQueryFilter] = None, **kwargs):
        """ProcessSchedulesQueryConfig

        :param query_filter: query_filter (optional)
        :type query_filter: Optional[ProcessSchedulesQueryConfigQueryFilter]
        """
        self.query_filter = self._define_object(
            query_filter, ProcessSchedulesQueryConfigQueryFilter
        ) if query_filter is not None else None
        self._kwargs = kwargs




from typing import Awaitable, Union
from .utils.to_async import to_async
from ..packaged_component import PackagedComponentService
from ...models import (
    PackagedComponent,
    PackagedComponentBulkResponse,
    PackagedComponentBulkRequest,
    PackagedComponentQueryResponse,
    PackagedComponentQueryConfig,
)


class PackagedComponentServiceAsync(PackagedComponentService):
    """
    Async Wrapper for PackagedComponentServiceAsync
    """

    def create_packaged_component(
        self, request_body: PackagedComponent = None
    ) -> Awaitable[Union[PackagedComponent, str]]:
        return to_async(super().create_packaged_component)(request_body)

    def get_packaged_component(
        self, id_: str
    ) -> Awaitable[Union[PackagedComponent, str]]:
        return to_async(super().get_packaged_component)(id_)

    def delete_packaged_component(self, id_: str) -> Awaitable[None]:
        return to_async(super().delete_packaged_component)(id_)

    def bulk_packaged_component(
        self, request_body: PackagedComponentBulkRequest = None
    ) -> Awaitable[Union[PackagedComponentBulkResponse, str]]:
        return to_async(super().bulk_packaged_component)(request_body)

    def query_packaged_component(
        self, request_body: PackagedComponentQueryConfig = None
    ) -> Awaitable[Union[PackagedComponentQueryResponse, str]]:
        return to_async(super().query_packaged_component)(request_body)

    def query_more_packaged_component(
        self, request_body: str
    ) -> Awaitable[Union[PackagedComponentQueryResponse, str]]:
        return to_async(super().query_more_packaged_component)(request_body)




from typing import Awaitable, Union
from .utils.to_async import to_async
from ..deployed_package import DeployedPackageService
from ...models import (
    DeployedPackage,
    DeployedPackageBulkResponse,
    DeployedPackageBulkRequest,
    DeployedPackageQueryResponse,
    DeployedPackageQueryConfig,
)


class DeployedPackageServiceAsync(DeployedPackageService):
    """
    Async Wrapper for DeployedPackageServiceAsync
    """

    def create_deployed_package(
        self, request_body: DeployedPackage = None
    ) -> Awaitable[Union[DeployedPackage, str]]:
        return to_async(super().create_deployed_package)(request_body)

    def get_deployed_package(self, id_: str) -> Awaitable[Union[DeployedPackage, str]]:
        return to_async(super().get_deployed_package)(id_)

    def delete_deployed_package(self, id_: str) -> Awaitable[None]:
        return to_async(super().delete_deployed_package)(id_)

    def bulk_deployed_package(
        self, request_body: DeployedPackageBulkRequest = None
    ) -> Awaitable[Union[DeployedPackageBulkResponse, str]]:
        return to_async(super().bulk_deployed_package)(request_body)

    def query_deployed_package(
        self, request_body: DeployedPackageQueryConfig = None
    ) -> Awaitable[Union[DeployedPackageQueryResponse, str]]:
        return to_async(super().query_deployed_package)(request_body)

    def query_more_deployed_package(
        self, request_body: str
    ) -> Awaitable[Union[DeployedPackageQueryResponse, str]]:
        return to_async(super().query_more_deployed_package)(request_body)




from __future__ import annotations
from enum import Enum
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .licensing import Licensing
from .molecule import Molecule


class AccountStatus(Enum):
    """An enumeration representing different categories.

    :cvar TRIAL: "trial"
    :vartype TRIAL: str
    :cvar ACTIVE: "active"
    :vartype ACTIVE: str
    :cvar SUSPENDED: "suspended"
    :vartype SUSPENDED: str
    :cvar DELETED: "deleted"
    :vartype DELETED: str
    :cvar UNLIMITED: "unlimited"
    :vartype UNLIMITED: str
    """

    TRIAL = "trial"
    ACTIVE = "active"
    SUSPENDED = "suspended"
    DELETED = "deleted"
    UNLIMITED = "unlimited"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, AccountStatus._member_map_.values()))


class SupportLevel(Enum):
    """An enumeration representing different categories.

    :cvar STANDARD: "standard"
    :vartype STANDARD: str
    :cvar PREMIER: "premier"
    :vartype PREMIER: str
    """

    STANDARD = "standard"
    PREMIER = "premier"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, SupportLevel._member_map_.values()))


@JsonMap(
    {
        "account_id": "accountId",
        "date_created": "dateCreated",
        "expiration_date": "expirationDate",
        "over_deployed": "overDeployed",
        "suggestions_enabled": "suggestionsEnabled",
        "support_access": "supportAccess",
        "support_level": "supportLevel",
        "widget_account": "widgetAccount",
    }
)
class Account(BaseModel):
    """Account

    :param account_id: The ID of the account., defaults to None
    :type account_id: str, optional
    :param date_created: The creation date of the account., defaults to None
    :type date_created: str, optional
    :param expiration_date: The scheduled expiration date of the account., defaults to None
    :type expiration_date: str, optional
    :param licensing: Indicates the number of connections used and purchased in each of the connector type and production/test classifications. The classifications include standard, smallBusiness, enterprise, and tradingPartner., defaults to None
    :type licensing: Licensing, optional
    :param molecule: Indicates the number of Runtime clusters available on an account and the number of Runtime clusters currently in use., defaults to None
    :type molecule: Molecule, optional
    :param name: The name of the account., defaults to None
    :type name: str, optional
    :param over_deployed: Indicates the state of an account if one or more additional deployments are made after all available connection licenses have been used for any of the connector class., defaults to None
    :type over_deployed: bool, optional
    :param status: The status of the account. The allowed values are active or deleted., defaults to None
    :type status: AccountStatus, optional
    :param suggestions_enabled: Identifies whether this account has the Boomi Suggest feature enabled., defaults to None
    :type suggestions_enabled: bool, optional
    :param support_access: Identifies whether this account allows support user access., defaults to None
    :type support_access: bool, optional
    :param support_level: The level of support for this account. The allowed values are standard *or premier., defaults to None
    :type support_level: SupportLevel, optional
    :param widget_account: widget_account, defaults to None
    :type widget_account: bool, optional
    """

    def __init__(
        self,
        account_id: str = SENTINEL,
        date_created: str = SENTINEL,
        expiration_date: str = SENTINEL,
        licensing: Licensing = SENTINEL,
        molecule: Molecule = SENTINEL,
        name: str = SENTINEL,
        over_deployed: bool = SENTINEL,
        status: AccountStatus = SENTINEL,
        suggestions_enabled: bool = SENTINEL,
        support_access: bool = SENTINEL,
        support_level: SupportLevel = SENTINEL,
        widget_account: bool = SENTINEL,
        **kwargs,
    ):
        """Account

        :param account_id: The ID of the account., defaults to None
        :type account_id: str, optional
        :param date_created: The creation date of the account., defaults to None
        :type date_created: str, optional
        :param expiration_date: The scheduled expiration date of the account., defaults to None
        :type expiration_date: str, optional
        :param licensing: Indicates the number of connections used and purchased in each of the connector type and production/test classifications. The classifications include standard, smallBusiness, enterprise, and tradingPartner., defaults to None
        :type licensing: Licensing, optional
        :param molecule: Indicates the number of Runtime clusters available on an account and the number of Runtime clusters currently in use., defaults to None
        :type molecule: Molecule, optional
        :param name: The name of the account., defaults to None
        :type name: str, optional
        :param over_deployed: Indicates the state of an account if one or more additional deployments are made after all available connection licenses have been used for any of the connector class., defaults to None
        :type over_deployed: bool, optional
        :param status: The status of the account. The allowed values are active or deleted., defaults to None
        :type status: AccountStatus, optional
        :param suggestions_enabled: Identifies whether this account has the Boomi Suggest feature enabled., defaults to None
        :type suggestions_enabled: bool, optional
        :param support_access: Identifies whether this account allows support user access., defaults to None
        :type support_access: bool, optional
        :param support_level: The level of support for this account. The allowed values are standard *or premier., defaults to None
        :type support_level: SupportLevel, optional
        :param widget_account: widget_account, defaults to None
        :type widget_account: bool, optional
        """
        if account_id is not SENTINEL:
            self.account_id = account_id
        if date_created is not SENTINEL:
            self.date_created = date_created
        if expiration_date is not SENTINEL:
            self.expiration_date = expiration_date
        if licensing is not SENTINEL:
            self.licensing = self._define_object(licensing, Licensing)
        if molecule is not SENTINEL:
            self.molecule = self._define_object(molecule, Molecule)
        if name is not SENTINEL:
            self.name = name
        if over_deployed is not SENTINEL:
            self.over_deployed = over_deployed
        if status is not SENTINEL:
            self.status = self._enum_matching(status, AccountStatus.list(), "status")
        if suggestions_enabled is not SENTINEL:
            self.suggestions_enabled = suggestions_enabled
        if support_access is not SENTINEL:
            self.support_access = support_access
        if support_level is not SENTINEL:
            self.support_level = self._enum_matching(
                support_level, SupportLevel.list(), "support_level"
            )
        if widget_account is not SENTINEL:
            self.widget_account = widget_account
        self._kwargs = kwargs




from __future__ import annotations
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .private_certificate import PrivateCertificate


@JsonMap(
    {
        "as2_id": "as2Id",
        "enabled_legacy_smime": "enabledLegacySMIME",
        "encryption_private_certificate": "encryptionPrivateCertificate",
        "mdn_signature_private_certificate": "mdnSignaturePrivateCertificate",
        "signing_private_certificate": "signingPrivateCertificate",
        "enabled_folded_headers": "enabledFoldedHeaders",
    }
)
class As2MyCompanyInfo(BaseModel):
    """As2MyCompanyInfo

    :param as2_id: as2_id
    :type as2_id: str
    :param enabled_legacy_smime: enabled_legacy_smime, defaults to None
    :type enabled_legacy_smime: bool, optional
    :param encryption_private_certificate: encryption_private_certificate
    :type encryption_private_certificate: PrivateCertificate
    :param mdn_signature_private_certificate: mdn_signature_private_certificate
    :type mdn_signature_private_certificate: PrivateCertificate
    :param signing_private_certificate: signing_private_certificate
    :type signing_private_certificate: PrivateCertificate
    :param enabled_folded_headers: enabled_folded_headers, defaults to None
    :type enabled_folded_headers: bool, optional
    """

    def __init__(
        self,
        as2_id: str = SENTINEL,
        encryption_private_certificate: PrivateCertificate = SENTINEL,
        mdn_signature_private_certificate: PrivateCertificate = SENTINEL,
        signing_private_certificate: PrivateCertificate = SENTINEL,
        enabled_legacy_smime: bool = SENTINEL,
        enabled_folded_headers: bool = SENTINEL,
        **kwargs,
    ):
        """As2MyCompanyInfo

        :param as2_id: as2_id, defaults to None
        :type as2_id: str, optional
        :param enabled_legacy_smime: enabled_legacy_smime, defaults to None
        :type enabled_legacy_smime: bool, optional
        :param encryption_private_certificate: encryption_private_certificate, defaults to None
        :type encryption_private_certificate: PrivateCertificate, optional
        :param mdn_signature_private_certificate: mdn_signature_private_certificate, defaults to None
        :type mdn_signature_private_certificate: PrivateCertificate, optional
        :param signing_private_certificate: signing_private_certificate, defaults to None
        :type signing_private_certificate: PrivateCertificate, optional
        :param enabled_folded_headers: enabled_folded_headers, defaults to None
        :type enabled_folded_headers: bool, optional
        """
        if as2_id is not SENTINEL:
            self.as2_id = as2_id
        if enabled_legacy_smime is not SENTINEL:
            self.enabled_legacy_smime = enabled_legacy_smime
        if encryption_private_certificate is not SENTINEL:
            self.encryption_private_certificate = self._define_object(
                encryption_private_certificate, PrivateCertificate
            )
        if mdn_signature_private_certificate is not SENTINEL:
            self.mdn_signature_private_certificate = self._define_object(
                mdn_signature_private_certificate, PrivateCertificate
            )
        if signing_private_certificate is not SENTINEL:
            self.signing_private_certificate = self._define_object(
                signing_private_certificate, PrivateCertificate
            )
        if enabled_folded_headers is not SENTINEL:
            self.enabled_folded_headers = enabled_folded_headers
        self._kwargs = kwargs




from typing import Awaitable, Union
from .utils.to_async import to_async
from ..component_atom_attachment import ComponentAtomAttachmentService
from ...models import (
    ComponentAtomAttachment,
    ComponentAtomAttachmentQueryResponse,
    ComponentAtomAttachmentQueryConfig,
)


class ComponentAtomAttachmentServiceAsync(ComponentAtomAttachmentService):
    """
    Async Wrapper for ComponentAtomAttachmentServiceAsync
    """

    def create_component_atom_attachment(
        self, request_body: ComponentAtomAttachment = None
    ) -> Awaitable[Union[ComponentAtomAttachment, str]]:
        return to_async(super().create_component_atom_attachment)(request_body)

    def query_component_atom_attachment(
        self, request_body: ComponentAtomAttachmentQueryConfig = None
    ) -> Awaitable[Union[ComponentAtomAttachmentQueryResponse, str]]:
        return to_async(super().query_component_atom_attachment)(request_body)

    def query_more_component_atom_attachment(
        self, request_body: str
    ) -> Awaitable[Union[ComponentAtomAttachmentQueryResponse, str]]:
        return to_async(super().query_more_component_atom_attachment)(request_body)

    def delete_component_atom_attachment(self, id_: str) -> Awaitable[None]:
        return to_async(super().delete_component_atom_attachment)(id_)




from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


@JsonMap({"process_id": "processId"})
class ProcessingGroupDefaultRouting(BaseModel):
    """ProcessingGroupDefaultRouting

    :param process_id: process_id, defaults to None
    :type process_id: str, optional
    """

    def __init__(self, process_id: str = SENTINEL, **kwargs):
        """ProcessingGroupDefaultRouting

        :param process_id: process_id, defaults to None
        :type process_id: str, optional
        """
        if process_id is not SENTINEL:
            self.process_id = process_id
        self._kwargs = kwargs




from typing import Awaitable, Union
from .utils.to_async import to_async
from ..execution_count_account import ExecutionCountAccountService
from ...models import (
    ExecutionCountAccountQueryResponse,
    ExecutionCountAccountQueryConfig,
)


class ExecutionCountAccountServiceAsync(ExecutionCountAccountService):
    """
    Async Wrapper for ExecutionCountAccountServiceAsync
    """

    def query_execution_count_account(
        self, request_body: ExecutionCountAccountQueryConfig = None
    ) -> Awaitable[Union[ExecutionCountAccountQueryResponse, str]]:
        return to_async(super().query_execution_count_account)(request_body)

    def query_more_execution_count_account(
        self, request_body: str
    ) -> Awaitable[Union[ExecutionCountAccountQueryResponse, str]]:
        return to_async(super().query_more_execution_count_account)(request_body)




from typing import Awaitable, Union
from .utils.to_async import to_async
from ..environment_map_extension_user_defined_function_summary import (
    EnvironmentMapExtensionUserDefinedFunctionSummaryService,
)
from ...models import (
    EnvironmentMapExtensionUserDefinedFunctionSummaryQueryResponse,
    EnvironmentMapExtensionUserDefinedFunctionSummaryQueryConfig,
)


class EnvironmentMapExtensionUserDefinedFunctionSummaryServiceAsync(
    EnvironmentMapExtensionUserDefinedFunctionSummaryService
):
    """
    Async Wrapper for EnvironmentMapExtensionUserDefinedFunctionSummaryServiceAsync
    """

    def query_environment_map_extension_user_defined_function_summary(
        self,
        request_body: EnvironmentMapExtensionUserDefinedFunctionSummaryQueryConfig = None,
    ) -> Awaitable[
        Union[EnvironmentMapExtensionUserDefinedFunctionSummaryQueryResponse, str]
    ]:
        return to_async(
            super().query_environment_map_extension_user_defined_function_summary
        )(request_body)

    def query_more_environment_map_extension_user_defined_function_summary(
        self, request_body: str
    ) -> Awaitable[
        Union[EnvironmentMapExtensionUserDefinedFunctionSummaryQueryResponse, str]
    ]:
        return to_async(
            super().query_more_environment_map_extension_user_defined_function_summary
        )(request_body)




from __future__ import annotations
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .organization_contact_info import OrganizationContactInfo


@JsonMap(
    {
        "organization_contact_info": "OrganizationContactInfo",
        "component_id": "componentId",
        "component_name": "componentName",
        "folder_id": "folderId",
        "folder_name": "folderName",
        "branch_id": "branchId",
        "branch_name": "branchName",
    }
)
class OrganizationComponent(BaseModel):
    """OrganizationComponent

    :param organization_contact_info: organization_contact_info
    :type organization_contact_info: OrganizationContactInfo
    :param component_id: A unique ID assigned by the system to the component., defaults to None
    :type component_id: str, optional
    :param component_name: A user-defined name for the component., defaults to None
    :type component_name: str, optional
    :param deleted: Indicates if the component is deleted. A value of `true` indicates a deleted status, whereas `false` indicates an active status., defaults to None
    :type deleted: bool, optional
    :param description: Description of the component.  \>**Note:** Although this field is in the object, operations do not support the field. For example, the system ignores the field if it is present in a QUERY, CREATE, or UPDATE request., defaults to None
    :type description: str, optional
    :param folder_id: The ID of the folder in which the component currently resides., defaults to None
    :type folder_id: int, optional
    :param folder_name: The folder location of the component within Component Explorer., defaults to None
    :type folder_name: str, optional
    :param branch_id: branch_id, defaults to None
    :type branch_id: str, optional
    :param branch_name: branch_name, defaults to None
    :type branch_name: str, optional
    """

    def __init__(
        self,
        organization_contact_info: OrganizationContactInfo,
        component_id: str = SENTINEL,
        component_name: str = SENTINEL,
        deleted: bool = SENTINEL,
        description: str = SENTINEL,
        folder_id: int = SENTINEL,
        folder_name: str = SENTINEL,
        branch_id: str = SENTINEL,
        branch_name: str = SENTINEL,
        **kwargs,
    ):
        """OrganizationComponent

        :param organization_contact_info: organization_contact_info
        :type organization_contact_info: OrganizationContactInfo
        :param component_id: A unique ID assigned by the system to the component., defaults to None
        :type component_id: str, optional
        :param component_name: A user-defined name for the component., defaults to None
        :type component_name: str, optional
        :param deleted: Indicates if the component is deleted. A value of `true` indicates a deleted status, whereas `false` indicates an active status., defaults to None
        :type deleted: bool, optional
        :param description: Description of the component.  \>**Note:** Although this field is in the object, operations do not support the field. For example, the system ignores the field if it is present in a QUERY, CREATE, or UPDATE request., defaults to None
        :type description: str, optional
        :param folder_id: The ID of the folder in which the component currently resides., defaults to None
        :type folder_id: int, optional
        :param folder_name: The folder location of the component within Component Explorer., defaults to None
        :type folder_name: str, optional
        :param branch_id: branch_id, defaults to None
        :type branch_id: str, optional
        :param branch_name: branch_name, defaults to None
        :type branch_name: str, optional
        """
        self.organization_contact_info = self._define_object(
            organization_contact_info, OrganizationContactInfo
        )
        if component_id is not SENTINEL:
            self.component_id = component_id
        if component_name is not SENTINEL:
            self.component_name = component_name
        if deleted is not SENTINEL:
            self.deleted = deleted
        if description is not SENTINEL:
            self.description = description
        if folder_id is not SENTINEL:
            self.folder_id = folder_id
        if folder_name is not SENTINEL:
            self.folder_name = folder_name
        if branch_id is not SENTINEL:
            self.branch_id = branch_id
        if branch_name is not SENTINEL:
            self.branch_name = branch_name
        self._kwargs = kwargs




from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .shared_web_server_user import SharedWebServerUser


@JsonMap({"enable_apim_internal_roles": "enableAPIMInternalRoles"})
class SharedWebServerUserManagement(BaseModel):
    """SharedWebServerUserManagement

    :param enable_apim_internal_roles: enable_apim_internal_roles, defaults to None
    :type enable_apim_internal_roles: bool, optional
    :param users: users, defaults to None
    :type users: List[SharedWebServerUser], optional
    """

    def __init__(
        self,
        enable_apim_internal_roles: bool = SENTINEL,
        users: List[SharedWebServerUser] = SENTINEL,
        **kwargs,
    ):
        """SharedWebServerUserManagement

        :param enable_apim_internal_roles: enable_apim_internal_roles, defaults to None
        :type enable_apim_internal_roles: bool, optional
        :param users: users, defaults to None
        :type users: List[SharedWebServerUser], optional
        """
        if enable_apim_internal_roles is not SENTINEL:
            self.enable_apim_internal_roles = enable_apim_internal_roles
        if users is not SENTINEL:
            self.users = self._define_list(users, SharedWebServerUser)
        self._kwargs = kwargs




from typing import Awaitable, Union
from .utils.to_async import to_async
from ..release_integration_pack import ReleaseIntegrationPackService
from ...models import ReleaseIntegrationPack


class ReleaseIntegrationPackServiceAsync(ReleaseIntegrationPackService):
    """
    Async Wrapper for ReleaseIntegrationPackServiceAsync
    """

    def create_release_integration_pack(
        self, request_body: ReleaseIntegrationPack = None
    ) -> Awaitable[Union[ReleaseIntegrationPack, str]]:
        return to_async(super().create_release_integration_pack)(request_body)

    def update_release_integration_pack(
        self, id_: str, request_body: ReleaseIntegrationPack = None
    ) -> Awaitable[Union[ReleaseIntegrationPack, str]]:
        return to_async(super().update_release_integration_pack)(id_, request_body)




from typing import Awaitable, Union
from .utils.to_async import to_async
from ..oftp2_connector_record import Oftp2ConnectorRecordService
from ...models import Oftp2ConnectorRecordQueryResponse, Oftp2ConnectorRecordQueryConfig


class Oftp2ConnectorRecordServiceAsync(Oftp2ConnectorRecordService):
    """
    Async Wrapper for Oftp2ConnectorRecordServiceAsync
    """

    def query_oftp2_connector_record(
        self, request_body: Oftp2ConnectorRecordQueryConfig = None
    ) -> Awaitable[Union[Oftp2ConnectorRecordQueryResponse, str]]:
        return to_async(super().query_oftp2_connector_record)(request_body)

    def query_more_oftp2_connector_record(
        self, request_body: str
    ) -> Awaitable[Union[Oftp2ConnectorRecordQueryResponse, str]]:
        return to_async(super().query_more_oftp2_connector_record)(request_body)




from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .map_extensions_output import MapExtensionsOutput


@JsonMap({"output": "Output"})
class MapExtensionsOutputs(BaseModel):
    """Lists the function's input and outputs according to their user-given names and keys. You must list inputs and outputs sequentially in order according to their key values. See the following row for more information. When creating or updating functions, it requires all input and output values in the request regardless if they are to be mapped or populated with a default value.

     The maximum number of inputs or outputs is 100.

    :param output: output, defaults to None
    :type output: List[MapExtensionsOutput], optional
    """

    def __init__(self, output: List[MapExtensionsOutput] = SENTINEL, **kwargs):
        """Lists the function's input and outputs according to their user-given names and keys. You must list inputs and outputs sequentially in order according to their key values. See the following row for more information. When creating or updating functions, it requires all input and output values in the request regardless if they are to be mapped or populated with a default value.

         The maximum number of inputs or outputs is 100.

        :param output: output, defaults to None
        :type output: List[MapExtensionsOutput], optional
        """
        if output is not SENTINEL:
            self.output = self._define_list(output, MapExtensionsOutput)
        self._kwargs = kwargs




from typing import Union
from .utils.validator import Validator
from .utils.base_service import BaseService
from ..net.transport.serializer import Serializer
from ..net.transport.api_error import ApiError
from ..net.environment.environment import Environment
from ..models.utils.cast_models import cast_models
from ..net.transport.utils import parse_xml_to_dict
from ..models import AsyncOperationTokenResult, ListQueuesAsyncResponse


class ListQueuesService(BaseService):

    @cast_models
    def async_token_list_queues(
        self, token: str
    ) -> Union[ListQueuesAsyncResponse, str]:
        """After receiving a 200 status code response, send a second GET request where {accountId} is the ID of the account authenticating the request and sessionId is the ID provided in the initial response.

        :param token: Takes in the token from a previous call to return a result.
        :type token: str
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: The parsed response data.
        :rtype: Union[ListQueuesAsyncResponse, str]
        """

        Validator(str).validate(token)

        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/async/ListQueues/response/{{token}}",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .add_path("token", token)
            .serialize()
            .set_method("GET")
        )

        response, status, content = self.send_request(serialized_request)
        if content == "application/json":
            return ListQueuesAsyncResponse._unmap(response)
        if content == "application/xml":
            return ListQueuesAsyncResponse._unmap(parse_xml_to_dict(response))
        raise ApiError("Error on deserializing the response.", status, response)

    @cast_models
    def async_get_list_queues(self, id_: str) -> Union[AsyncOperationTokenResult, str]:
        """To retrieve a list of message queues, Send an HTTP GET where accountId is the account that you are authenticating with and containerId is the ID of the Runtime, Runtime cluster, or Runtime cloud which owns the message queue that you want to retrieve.
         >**Note:** You can find the Account ID for an account by navigating to Settings > Account Information and Setup in the user interface. Additionally, you can find the container ID by navigating to Manage > Runtime Management and viewing the Runtime ID value on the Runtime Information panel for a selected Runtime, Runtime cluster, or Runtime cloud.

        :param id_: id_
        :type id_: str
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: The parsed response data.
        :rtype: Union[AsyncOperationTokenResult, str]
        """

        Validator(str).validate(id_)

        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/async/ListQueues/{{id}}",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .add_path("id", id_)
            .serialize()
            .set_method("GET")
        )

        response, status, content = self.send_request(serialized_request)
        if content == "application/json":
            return AsyncOperationTokenResult._unmap(response)
        if content == "application/xml":
            return AsyncOperationTokenResult._unmap(parse_xml_to_dict(response))
        raise ApiError("Error on deserializing the response.", status, response)




from __future__ import annotations
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .publisher_integration_pack_expression import PublisherIntegrationPackExpression


@JsonMap({})
class PublisherIntegrationPackQueryConfigQueryFilter(BaseModel):
    """PublisherIntegrationPackQueryConfigQueryFilter

    :param expression: expression
    :type expression: PublisherIntegrationPackExpression
    """

    def __init__(self, expression: PublisherIntegrationPackExpression, **kwargs):
        """PublisherIntegrationPackQueryConfigQueryFilter

        :param expression: expression
        :type expression: PublisherIntegrationPackExpression
        """
        self.expression = self._define_object(
            expression, PublisherIntegrationPackExpression
        )
        self._kwargs = kwargs


@JsonMap({"query_filter": "QueryFilter"})
class PublisherIntegrationPackQueryConfig(BaseModel):
    """PublisherIntegrationPackQueryConfig

    :param query_filter: query_filter
    :type query_filter: PublisherIntegrationPackQueryConfigQueryFilter
    """

    def __init__(
        self, query_filter: PublisherIntegrationPackQueryConfigQueryFilter, **kwargs
    ):
        """PublisherIntegrationPackQueryConfig

        :param query_filter: query_filter
        :type query_filter: PublisherIntegrationPackQueryConfigQueryFilter
        """
        self.query_filter = self._define_object(
            query_filter, PublisherIntegrationPackQueryConfigQueryFilter
        )
        self._kwargs = kwargs




from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .dynamic_process_property import DynamicProcessProperty


@JsonMap({"dynamic_process_property": "DynamicProcessProperty"})
class ExecutionRequestDynamicProcessProperties(BaseModel):
    """The full list of Dynamic Process properties within the specified Runtime, Runtime cluster, or cloud, where each property is defined by their name and value.

    :param dynamic_process_property: dynamic_process_property, defaults to None
    :type dynamic_process_property: List[DynamicProcessProperty], optional
    """

    def __init__(
        self,
        dynamic_process_property: List[DynamicProcessProperty] = SENTINEL,
        **kwargs,
    ):
        """The full list of Dynamic Process properties within the specified Runtime, Runtime cluster, or cloud, where each property is defined by their name and value.

        :param dynamic_process_property: dynamic_process_property, defaults to None
        :type dynamic_process_property: List[DynamicProcessProperty], optional
        """
        if dynamic_process_property is not SENTINEL:
            self.dynamic_process_property = self._define_list(
                dynamic_process_property, DynamicProcessProperty
            )
        self._kwargs = kwargs




from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


@JsonMap({})
class SharedWebServerLoginModuleOption(BaseModel):
    """SharedWebServerLoginModuleOption

    :param encrypt: encrypt, defaults to None
    :type encrypt: bool, optional
    :param name: name
    :type name: str
    :param value: value
    :type value: str
    """

    def __init__(self, name: str, value: str, encrypt: bool = SENTINEL, **kwargs):
        """SharedWebServerLoginModuleOption

        :param encrypt: encrypt, defaults to None
        :type encrypt: bool, optional
        :param name: name
        :type name: str
        :param value: value
        :type value: str
        """
        if encrypt is not SENTINEL:
            self.encrypt = encrypt
        self.name = name
        self.value = value
        self._kwargs = kwargs




from __future__ import annotations
from enum import Enum
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .http_endpoint import HttpEndpoint
from .http_request_parameters import HttpRequestParameters
from .httpo_auth_credentials import HttpoAuthCredentials


class GrantType(Enum):
    """An enumeration representing different categories.

    :cvar CODE: "code"
    :vartype CODE: str
    :cvar CLIENTCREDENTIALS: "client_credentials"
    :vartype CLIENTCREDENTIALS: str
    :cvar PASSWORD: "password"
    :vartype PASSWORD: str
    """

    CODE = "code"
    CLIENTCREDENTIALS = "client_credentials"
    PASSWORD = "password"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, GrantType._member_map_.values()))


@JsonMap(
    {
        "access_token_endpoint": "accessTokenEndpoint",
        "access_token_parameters": "accessTokenParameters",
        "authorization_parameters": "authorizationParameters",
        "authorization_token_endpoint": "authorizationTokenEndpoint",
        "grant_type": "grantType",
    }
)
class HttpoAuth2Settings(BaseModel):
    """HttpoAuth2Settings

    :param access_token_endpoint: access_token_endpoint, defaults to None
    :type access_token_endpoint: HttpEndpoint, optional
    :param access_token_parameters: access_token_parameters, defaults to None
    :type access_token_parameters: HttpRequestParameters, optional
    :param authorization_parameters: authorization_parameters, defaults to None
    :type authorization_parameters: HttpRequestParameters, optional
    :param authorization_token_endpoint: authorization_token_endpoint, defaults to None
    :type authorization_token_endpoint: HttpEndpoint, optional
    :param credentials: credentials, defaults to None
    :type credentials: HttpoAuthCredentials, optional
    :param grant_type: grant_type, defaults to None
    :type grant_type: GrantType, optional
    :param scope: scope, defaults to None
    :type scope: str, optional
    """

    def __init__(
        self,
        access_token_endpoint: HttpEndpoint = SENTINEL,
        access_token_parameters: HttpRequestParameters = SENTINEL,
        authorization_parameters: HttpRequestParameters = SENTINEL,
        authorization_token_endpoint: HttpEndpoint = SENTINEL,
        credentials: HttpoAuthCredentials = SENTINEL,
        grant_type: GrantType = SENTINEL,
        scope: str = SENTINEL,
        **kwargs,
    ):
        """HttpoAuth2Settings

        :param access_token_endpoint: access_token_endpoint, defaults to None
        :type access_token_endpoint: HttpEndpoint, optional
        :param access_token_parameters: access_token_parameters, defaults to None
        :type access_token_parameters: HttpRequestParameters, optional
        :param authorization_parameters: authorization_parameters, defaults to None
        :type authorization_parameters: HttpRequestParameters, optional
        :param authorization_token_endpoint: authorization_token_endpoint, defaults to None
        :type authorization_token_endpoint: HttpEndpoint, optional
        :param credentials: credentials, defaults to None
        :type credentials: HttpoAuthCredentials, optional
        :param grant_type: grant_type, defaults to None
        :type grant_type: GrantType, optional
        :param scope: scope, defaults to None
        :type scope: str, optional
        """
        if access_token_endpoint is not SENTINEL:
            self.access_token_endpoint = self._define_object(
                access_token_endpoint, HttpEndpoint
            )
        if access_token_parameters is not SENTINEL:
            self.access_token_parameters = self._define_object(
                access_token_parameters, HttpRequestParameters
            )
        if authorization_parameters is not SENTINEL:
            self.authorization_parameters = self._define_object(
                authorization_parameters, HttpRequestParameters
            )
        if authorization_token_endpoint is not SENTINEL:
            self.authorization_token_endpoint = self._define_object(
                authorization_token_endpoint, HttpEndpoint
            )
        if credentials is not SENTINEL:
            self.credentials = self._define_object(credentials, HttpoAuthCredentials)
        if grant_type is not SENTINEL:
            self.grant_type = self._enum_matching(
                grant_type, GrantType.list(), "grant_type"
            )
        if scope is not SENTINEL:
            self.scope = scope
        self._kwargs = kwargs




from typing import Awaitable, Union
from .utils.to_async import to_async
from ..connector_document import ConnectorDocumentService
from ...models import ConnectorDocumentDownload, ConnectorDocument


class ConnectorDocumentServiceAsync(ConnectorDocumentService):
    """
    Async Wrapper for ConnectorDocumentServiceAsync
    """

    def create_connector_document(
        self, request_body: ConnectorDocument = None
    ) -> Awaitable[Union[ConnectorDocumentDownload, str]]:
        return to_async(super().create_connector_document)(request_body)




from typing import Union
from .utils.validator import Validator
from .utils.base_service import BaseService
from ..net.transport.serializer import Serializer
from ..net.transport.api_error import ApiError
from ..net.environment.environment import Environment
from ..models.utils.cast_models import cast_models
from ..net.transport.utils import parse_xml_to_dict
from ..models import (
    AsyncOperationTokenResult,
    AtomSecurityPolicies,
    AtomSecurityPoliciesAsyncResponse,
)


class AtomSecurityPoliciesService(BaseService):

    @cast_models
    def update_atom_security_policies(
        self, id_: str, request_body: AtomSecurityPolicies = None
    ) -> Union[AtomSecurityPolicies, str]:
        """Updates the security policy for the specified Runtime cloud or Runtime cluster. You can add, update, or delete permissions by using the UPDATE operation. You can add custom Java runtime permissions you specify in an UPDATE operation to the appropriate High-security policy file. In addition, all High-security policy files contain custom permissions that you specify in the <common> section.
         As confirmation of the changes made, the UPDATE operation returns a copy of the request.

        :param request_body: The request body., defaults to None
        :type request_body: AtomSecurityPolicies, optional
        :param id_: The runtime (container) id for the applicable runtime (accepts only Runtime cloud cluster and regular Runtime cluster types, no basic runtimes or cloud attachments).
        :type id_: str
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: The parsed response data.
        :rtype: Union[AtomSecurityPolicies, str]
        """

        Validator(AtomSecurityPolicies).is_optional().validate(request_body)
        Validator(str).validate(id_)

        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/AtomSecurityPolicies/{{id}}",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .add_path("id", id_)
            .serialize()
            .set_method("POST")
            .set_body(request_body)
        )

        response, status, content = self.send_request(serialized_request)
        if content == "application/json":
            return AtomSecurityPolicies._unmap(response)
        if content == "application/xml":
            return AtomSecurityPolicies._unmap(parse_xml_to_dict(response))
        raise ApiError("Error on deserializing the response.", status, response)

    @cast_models
    def async_get_atom_security_policies(
        self, id_: str
    ) -> Union[AsyncOperationTokenResult, str]:
        """The initial GET operation returns a security policy token for the specified Runtime cloud or Runtime cluster. Subsequent GET operations return status code 202 (while the request is in progress) or the custom contents of a security policy based on the token that was returned.

         The GET operation returns only custom runtime permissions that you added to the security policy, not the entire policy file. If you did not update the security policy for a given Runtime cloud or Runtime cluster, the response to a GET operation is empty.

        :param id_: The runtime (container) id for the applicable runtime (accepts only Runtime cloud cluster and regular runtime cluster types, no basic runtimes or cloud attachments).
        :type id_: str
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: The parsed response data.
        :rtype: Union[AsyncOperationTokenResult, str]
        """

        Validator(str).validate(id_)

        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/async/AtomSecurityPolicies/{{id}}",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .add_path("id", id_)
            .serialize()
            .set_method("GET")
        )

        response, status, content = self.send_request(serialized_request)
        if content == "application/json":
            return AsyncOperationTokenResult._unmap(response)
        if content == "application/xml":
            return AsyncOperationTokenResult._unmap(parse_xml_to_dict(response))
        raise ApiError("Error on deserializing the response.", status, response)

    @cast_models
    def async_token_atom_security_policies(
        self, token: str
    ) -> Union[AtomSecurityPoliciesAsyncResponse, str]:
        """Using the token from the initial GET response, send an HTTP GET where accountId is the account with which you are authenticating.

         Custom Java runtime permissions listed in the `<common>` section apply to all High security policy files (procrunner-HIGH.policy, procbrowser-HIGH.policy, and procworker-HIGH.policy). Custom permissions listed in a specific section, such as `<runner>`, apply only to the associated security policy file.

        :param token: Takes in the token from a previous call to return a result.
        :type token: str
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: The parsed response data.
        :rtype: Union[AtomSecurityPoliciesAsyncResponse, str]
        """

        Validator(str).validate(token)

        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/async/AtomSecurityPolicies/response/{{token}}",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .add_path("token", token)
            .serialize()
            .set_method("GET")
        )

        response, status, content = self.send_request(serialized_request)
        if content == "application/json":
            return AtomSecurityPoliciesAsyncResponse._unmap(response)
        if content == "application/xml":
            return AtomSecurityPoliciesAsyncResponse._unmap(parse_xml_to_dict(response))
        raise ApiError("Error on deserializing the response.", status, response)




from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


@JsonMap({})
class License(BaseModel):
    """License

    :param purchased: purchased, defaults to None
    :type purchased: int, optional
    :param used: used, defaults to None
    :type used: int, optional
    """

    def __init__(self, purchased: int = SENTINEL, used: int = SENTINEL, **kwargs):
        """License

        :param purchased: purchased, defaults to None
        :type purchased: int, optional
        :param used: used, defaults to None
        :type used: int, optional
        """
        if purchased is not SENTINEL:
            self.purchased = purchased
        if used is not SENTINEL:
            self.used = used
        self._kwargs = kwargs




from typing import Awaitable, Union
from .utils.to_async import to_async
from ..integration_pack_atom_attachment import IntegrationPackAtomAttachmentService
from ...models import (
    IntegrationPackAtomAttachment,
    IntegrationPackAtomAttachmentQueryResponse,
    IntegrationPackAtomAttachmentQueryConfig,
)


class IntegrationPackAtomAttachmentServiceAsync(IntegrationPackAtomAttachmentService):
    """
    Async Wrapper for IntegrationPackAtomAttachmentServiceAsync
    """

    def create_integration_pack_atom_attachment(
        self, request_body: IntegrationPackAtomAttachment = None
    ) -> Awaitable[Union[IntegrationPackAtomAttachment, str]]:
        return to_async(super().create_integration_pack_atom_attachment)(request_body)

    def query_integration_pack_atom_attachment(
        self, request_body: IntegrationPackAtomAttachmentQueryConfig = None
    ) -> Awaitable[Union[IntegrationPackAtomAttachmentQueryResponse, str]]:
        return to_async(super().query_integration_pack_atom_attachment)(request_body)

    def query_more_integration_pack_atom_attachment(
        self, request_body: str
    ) -> Awaitable[Union[IntegrationPackAtomAttachmentQueryResponse, str]]:
        return to_async(super().query_more_integration_pack_atom_attachment)(
            request_body
        )

    def delete_integration_pack_atom_attachment(self, id_: str) -> Awaitable[None]:
        return to_async(super().delete_integration_pack_atom_attachment)(id_)




from typing import Awaitable, Union
from .utils.to_async import to_async
from ..account_group_integration_pack import AccountGroupIntegrationPackService
from ...models import (
    AccountGroupIntegrationPack,
    AccountGroupIntegrationPackBulkResponse,
    AccountGroupIntegrationPackBulkRequest,
    AccountGroupIntegrationPackQueryResponse,
    AccountGroupIntegrationPackQueryConfig,
)


class AccountGroupIntegrationPackServiceAsync(AccountGroupIntegrationPackService):
    """
    Async Wrapper for AccountGroupIntegrationPackServiceAsync
    """

    def create_account_group_integration_pack(
        self, request_body: AccountGroupIntegrationPack = None
    ) -> Awaitable[Union[AccountGroupIntegrationPack, str]]:
        return to_async(super().create_account_group_integration_pack)(request_body)

    def get_account_group_integration_pack(
        self, id_: str
    ) -> Awaitable[Union[AccountGroupIntegrationPack, str]]:
        return to_async(super().get_account_group_integration_pack)(id_)

    def delete_account_group_integration_pack(self, id_: str) -> Awaitable[None]:
        return to_async(super().delete_account_group_integration_pack)(id_)

    def bulk_account_group_integration_pack(
        self, request_body: AccountGroupIntegrationPackBulkRequest = None
    ) -> Awaitable[Union[AccountGroupIntegrationPackBulkResponse, str]]:
        return to_async(super().bulk_account_group_integration_pack)(request_body)

    def query_account_group_integration_pack(
        self, request_body: AccountGroupIntegrationPackQueryConfig = None
    ) -> Awaitable[Union[AccountGroupIntegrationPackQueryResponse, str]]:
        return to_async(super().query_account_group_integration_pack)(request_body)

    def query_more_account_group_integration_pack(
        self, request_body: str
    ) -> Awaitable[Union[AccountGroupIntegrationPackQueryResponse, str]]:
        return to_async(super().query_more_account_group_integration_pack)(request_body)




from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .cross_reference import CrossReference


@JsonMap({"cross_reference": "crossReference"})
class CrossReferences(BaseModel):
    """CrossReferences

    :param cross_reference: cross_reference, defaults to None
    :type cross_reference: List[CrossReference], optional
    """

    def __init__(self, cross_reference: List[CrossReference] = SENTINEL, **kwargs):
        """CrossReferences

        :param cross_reference: cross_reference, defaults to None
        :type cross_reference: List[CrossReference], optional
        """
        if cross_reference is not SENTINEL:
            self.cross_reference = self._define_list(cross_reference, CrossReference)
        self._kwargs = kwargs




from __future__ import annotations
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .map_extensions_cross_reference_lookup import MapExtensionsCrossReferenceLookup
from .map_extensions_doc_cache_lookup import MapExtensionsDocCacheLookup
from .map_extensions_document_property import MapExtensionsDocumentProperty
from .map_extensions_japanese_character_conversion import (
    MapExtensionsJapaneseCharacterConversion,
)
from .map_extensions_scripting import MapExtensionsScripting
from .map_extensions_sequential_value import MapExtensionsSequentialValue
from .map_extensions_simple_lookup import MapExtensionsSimpleLookup
from .map_extensions_string_concat import MapExtensionsStringConcat
from .map_extensions_string_split import MapExtensionsStringSplit
from .map_extensions_user_defined_function import MapExtensionsUserDefinedFunction


@JsonMap(
    {
        "cross_reference_lookup": "CrossReferenceLookup",
        "doc_cache_lookup": "DocCacheLookup",
        "document_property": "DocumentProperty",
        "japanese_character_conversion": "JapaneseCharacterConversion",
        "scripting": "Scripting",
        "sequential_value": "SequentialValue",
        "simple_lookup": "SimpleLookup",
        "string_concat": "StringConcat",
        "string_split": "StringSplit",
        "user_defined_function": "UserDefinedFunction",
    }
)
class MapExtensionsConfiguration(BaseModel):
    """MapExtensionsConfiguration

    :param cross_reference_lookup: cross_reference_lookup, defaults to None
    :type cross_reference_lookup: MapExtensionsCrossReferenceLookup, optional
    :param doc_cache_lookup: doc_cache_lookup, defaults to None
    :type doc_cache_lookup: MapExtensionsDocCacheLookup, optional
    :param document_property: document_property, defaults to None
    :type document_property: MapExtensionsDocumentProperty, optional
    :param japanese_character_conversion: japanese_character_conversion, defaults to None
    :type japanese_character_conversion: MapExtensionsJapaneseCharacterConversion, optional
    :param scripting: scripting, defaults to None
    :type scripting: MapExtensionsScripting, optional
    :param sequential_value: sequential_value, defaults to None
    :type sequential_value: MapExtensionsSequentialValue, optional
    :param simple_lookup: simple_lookup, defaults to None
    :type simple_lookup: MapExtensionsSimpleLookup, optional
    :param string_concat: string_concat, defaults to None
    :type string_concat: MapExtensionsStringConcat, optional
    :param string_split: string_split, defaults to None
    :type string_split: MapExtensionsStringSplit, optional
    :param user_defined_function: user_defined_function, defaults to None
    :type user_defined_function: MapExtensionsUserDefinedFunction, optional
    """

    def __init__(
        self,
        cross_reference_lookup: MapExtensionsCrossReferenceLookup = SENTINEL,
        doc_cache_lookup: MapExtensionsDocCacheLookup = SENTINEL,
        document_property: MapExtensionsDocumentProperty = SENTINEL,
        japanese_character_conversion: MapExtensionsJapaneseCharacterConversion = SENTINEL,
        scripting: MapExtensionsScripting = SENTINEL,
        sequential_value: MapExtensionsSequentialValue = SENTINEL,
        simple_lookup: MapExtensionsSimpleLookup = SENTINEL,
        string_concat: MapExtensionsStringConcat = SENTINEL,
        string_split: MapExtensionsStringSplit = SENTINEL,
        user_defined_function: MapExtensionsUserDefinedFunction = SENTINEL,
        **kwargs,
    ):
        """MapExtensionsConfiguration

        :param cross_reference_lookup: cross_reference_lookup, defaults to None
        :type cross_reference_lookup: MapExtensionsCrossReferenceLookup, optional
        :param doc_cache_lookup: doc_cache_lookup, defaults to None
        :type doc_cache_lookup: MapExtensionsDocCacheLookup, optional
        :param document_property: document_property, defaults to None
        :type document_property: MapExtensionsDocumentProperty, optional
        :param japanese_character_conversion: japanese_character_conversion, defaults to None
        :type japanese_character_conversion: MapExtensionsJapaneseCharacterConversion, optional
        :param scripting: scripting, defaults to None
        :type scripting: MapExtensionsScripting, optional
        :param sequential_value: sequential_value, defaults to None
        :type sequential_value: MapExtensionsSequentialValue, optional
        :param simple_lookup: simple_lookup, defaults to None
        :type simple_lookup: MapExtensionsSimpleLookup, optional
        :param string_concat: string_concat, defaults to None
        :type string_concat: MapExtensionsStringConcat, optional
        :param string_split: string_split, defaults to None
        :type string_split: MapExtensionsStringSplit, optional
        :param user_defined_function: user_defined_function, defaults to None
        :type user_defined_function: MapExtensionsUserDefinedFunction, optional
        """
        if cross_reference_lookup is not SENTINEL:
            self.cross_reference_lookup = self._define_object(
                cross_reference_lookup, MapExtensionsCrossReferenceLookup
            )
        if doc_cache_lookup is not SENTINEL:
            self.doc_cache_lookup = self._define_object(
                doc_cache_lookup, MapExtensionsDocCacheLookup
            )
        if document_property is not SENTINEL:
            self.document_property = self._define_object(
                document_property, MapExtensionsDocumentProperty
            )
        if japanese_character_conversion is not SENTINEL:
            self.japanese_character_conversion = self._define_object(
                japanese_character_conversion, MapExtensionsJapaneseCharacterConversion
            )
        if scripting is not SENTINEL:
            self.scripting = self._define_object(scripting, MapExtensionsScripting)
        if sequential_value is not SENTINEL:
            self.sequential_value = self._define_object(
                sequential_value, MapExtensionsSequentialValue
            )
        if simple_lookup is not SENTINEL:
            self.simple_lookup = self._define_object(
                simple_lookup, MapExtensionsSimpleLookup
            )
        if string_concat is not SENTINEL:
            self.string_concat = self._define_object(
                string_concat, MapExtensionsStringConcat
            )
        if string_split is not SENTINEL:
            self.string_split = self._define_object(
                string_split, MapExtensionsStringSplit
            )
        if user_defined_function is not SENTINEL:
            self.user_defined_function = self._define_object(
                user_defined_function, MapExtensionsUserDefinedFunction
            )
        self._kwargs = kwargs




from __future__ import annotations
from enum import Enum
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .http_auth_settings import HttpAuthSettings
from .httpo_auth2_settings import HttpoAuth2Settings
from .httpo_auth_settings import HttpoAuthSettings
from .httpssl_options import HttpsslOptions


class HttpSettingsAuthenticationType(Enum):
    """An enumeration representing different categories.

    :cvar NONE: "NONE"
    :vartype NONE: str
    :cvar BASIC: "BASIC"
    :vartype BASIC: str
    :cvar PASSWORDDIGEST: "PASSWORD_DIGEST"
    :vartype PASSWORDDIGEST: str
    :cvar CUSTOM: "CUSTOM"
    :vartype CUSTOM: str
    :cvar OAUTH: "OAUTH"
    :vartype OAUTH: str
    :cvar OAUTH2: "OAUTH2"
    :vartype OAUTH2: str
    """

    NONE = "NONE"
    BASIC = "BASIC"
    PASSWORDDIGEST = "PASSWORD_DIGEST"
    CUSTOM = "CUSTOM"
    OAUTH = "OAUTH"
    OAUTH2 = "OAUTH2"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(lambda x: x.value, HttpSettingsAuthenticationType._member_map_.values())
        )


class CookieScope(Enum):
    """An enumeration representing different categories.

    :cvar IGNORED: "IGNORED"
    :vartype IGNORED: str
    :cvar GLOBAL: "GLOBAL"
    :vartype GLOBAL: str
    :cvar CONNECTORSHAPE: "CONNECTOR_SHAPE"
    :vartype CONNECTORSHAPE: str
    """

    IGNORED = "IGNORED"
    GLOBAL = "GLOBAL"
    CONNECTORSHAPE = "CONNECTOR_SHAPE"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, CookieScope._member_map_.values()))


@JsonMap(
    {
        "http_auth_settings": "HTTPAuthSettings",
        "httpo_auth2_settings": "HTTPOAuth2Settings",
        "httpo_auth_settings": "HTTPOAuthSettings",
        "httpssl_options": "HTTPSSLOptions",
        "authentication_type": "authenticationType",
        "connect_timeout": "connectTimeout",
        "cookie_scope": "cookieScope",
        "read_timeout": "readTimeout",
        "use_basic_auth": "useBasicAuth",
        "use_custom_auth": "useCustomAuth",
        "use_default_settings": "useDefaultSettings",
    }
)
class HttpSettings(BaseModel):
    """HttpSettings

    :param http_auth_settings: http_auth_settings, defaults to None
    :type http_auth_settings: HttpAuthSettings, optional
    :param httpo_auth2_settings: httpo_auth2_settings, defaults to None
    :type httpo_auth2_settings: HttpoAuth2Settings, optional
    :param httpo_auth_settings: httpo_auth_settings, defaults to None
    :type httpo_auth_settings: HttpoAuthSettings, optional
    :param httpssl_options: httpssl_options, defaults to None
    :type httpssl_options: HttpsslOptions, optional
    :param authentication_type: authentication_type, defaults to None
    :type authentication_type: HttpSettingsAuthenticationType, optional
    :param connect_timeout: connect_timeout, defaults to None
    :type connect_timeout: int, optional
    :param cookie_scope: cookie_scope, defaults to None
    :type cookie_scope: CookieScope, optional
    :param read_timeout: read_timeout, defaults to None
    :type read_timeout: int, optional
    :param url: url, defaults to None
    :type url: str, optional
    :param use_basic_auth: use_basic_auth, defaults to None
    :type use_basic_auth: bool, optional
    :param use_custom_auth: use_custom_auth, defaults to None
    :type use_custom_auth: bool, optional
    :param use_default_settings: use_default_settings, defaults to None
    :type use_default_settings: bool, optional
    """

    def __init__(
        self,
        authentication_type: HttpSettingsAuthenticationType = SENTINEL,
        connect_timeout: int = SENTINEL,
        cookie_scope: CookieScope = SENTINEL,
        http_auth_settings: HttpAuthSettings = SENTINEL,
        httpo_auth2_settings: HttpoAuth2Settings = SENTINEL,
        httpo_auth_settings: HttpoAuthSettings = SENTINEL,
        httpssl_options: HttpsslOptions = SENTINEL,
        read_timeout: int = SENTINEL,
        url: str = SENTINEL,
        use_basic_auth: bool = SENTINEL,
        use_custom_auth: bool = SENTINEL,
        use_default_settings: bool = SENTINEL,
        **kwargs,
    ):
        """HttpSettings

        :param http_auth_settings: http_auth_settings, defaults to None
        :type http_auth_settings: HttpAuthSettings, optional
        :param httpo_auth2_settings: httpo_auth2_settings, defaults to None
        :type httpo_auth2_settings: HttpoAuth2Settings, optional
        :param httpo_auth_settings: httpo_auth_settings, defaults to None
        :type httpo_auth_settings: HttpoAuthSettings, optional
        :param httpssl_options: httpssl_options, defaults to None
        :type httpssl_options: HttpsslOptions, optional
        :param authentication_type: authentication_type, defaults to None
        :type authentication_type: HttpSettingsAuthenticationType, optional
        :param connect_timeout: connect_timeout, defaults to None
        :type connect_timeout: int, optional
        :param cookie_scope: cookie_scope, defaults to None
        :type cookie_scope: CookieScope, optional
        :param read_timeout: read_timeout, defaults to None
        :type read_timeout: int, optional
        :param url: url, defaults to None
        :type url: str, optional
        :param use_basic_auth: use_basic_auth, defaults to None
        :type use_basic_auth: bool, optional
        :param use_custom_auth: use_custom_auth, defaults to None
        :type use_custom_auth: bool, optional
        :param use_default_settings: use_default_settings, defaults to None
        :type use_default_settings: bool, optional
        """
        if http_auth_settings is not SENTINEL:
            self.http_auth_settings = self._define_object(
                http_auth_settings, HttpAuthSettings
            )
        if httpo_auth2_settings is not SENTINEL:
            self.httpo_auth2_settings = self._define_object(
                httpo_auth2_settings, HttpoAuth2Settings
            )
        if httpo_auth_settings is not SENTINEL:
            self.httpo_auth_settings = self._define_object(
                httpo_auth_settings, HttpoAuthSettings
            )
        if httpssl_options is not SENTINEL:
            self.httpssl_options = self._define_object(httpssl_options, HttpsslOptions)
        if authentication_type is not SENTINEL:
            self.authentication_type = self._enum_matching(
                authentication_type,
                HttpSettingsAuthenticationType.list(),
                "authentication_type",
            )
        if connect_timeout is not SENTINEL:
            self.connect_timeout = connect_timeout
        if cookie_scope is not SENTINEL:
            self.cookie_scope = self._enum_matching(
                cookie_scope, CookieScope.list(), "cookie_scope"
            )
        if read_timeout is not SENTINEL:
            self.read_timeout = read_timeout
        if url is not SENTINEL:
            self.url = url
        if use_basic_auth is not SENTINEL:
            self.use_basic_auth = use_basic_auth
        if use_custom_auth is not SENTINEL:
            self.use_custom_auth = use_custom_auth
        if use_default_settings is not SENTINEL:
            self.use_default_settings = use_default_settings
        self._kwargs = kwargs




from __future__ import annotations
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .custom_control_info import CustomControlInfo
from .custom_options import CustomOptions


@JsonMap(
    {
        "custom_control_info": "CustomControlInfo",
        "custom_options": "CustomOptions",
        "custom_standard_id": "customStandardId",
    }
)
class CustomPartnerInfo(BaseModel):
    """CustomPartnerInfo

    :param custom_control_info: custom_control_info
    :type custom_control_info: CustomControlInfo
    :param custom_options: custom_options
    :type custom_options: CustomOptions
    :param custom_standard_id: ID of the Custom Document Standard., defaults to None
    :type custom_standard_id: str, optional
    """

    def __init__(
        self,
        custom_control_info: CustomControlInfo = SENTINEL,
        custom_options: CustomOptions = SENTINEL,
        custom_standard_id: str = SENTINEL,
        **kwargs,
    ):
        """CustomPartnerInfo

        :param custom_control_info: custom_control_info, defaults to None
        :type custom_control_info: CustomControlInfo, optional
        :param custom_options: custom_options, defaults to None
        :type custom_options: CustomOptions, optional
        :param custom_standard_id: ID of the Custom Document Standard., defaults to None
        :type custom_standard_id: str, optional
        """
        if custom_control_info is not SENTINEL:
            self.custom_control_info = self._define_object(
                custom_control_info, CustomControlInfo
            )
        if custom_options is not SENTINEL:
            self.custom_options = self._define_object(custom_options, CustomOptions)
        if custom_standard_id is not SENTINEL:
            self.custom_standard_id = custom_standard_id
        self._kwargs = kwargs




from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .pgp_certificate import PgpCertificate


@JsonMap({"pgp_certificate": "PGPCertificate"})
class PgpCertificates(BaseModel):
    """PgpCertificates

    :param pgp_certificate: pgp_certificate, defaults to None
    :type pgp_certificate: List[PgpCertificate], optional
    """

    def __init__(self, pgp_certificate: List[PgpCertificate] = SENTINEL, **kwargs):
        """PgpCertificates

        :param pgp_certificate: pgp_certificate, defaults to None
        :type pgp_certificate: List[PgpCertificate], optional
        """
        if pgp_certificate is not SENTINEL:
            self.pgp_certificate = self._define_list(pgp_certificate, PgpCertificate)
        self._kwargs = kwargs




import asyncio
from typing import TypeVar, Awaitable, Callable

T = TypeVar("T")


def to_async(sync_func: Callable[..., T]) -> Callable[..., Awaitable[T]]:
    """
    Converts a synchronous function to an asynchronous function.

    :param sync_func: The synchronous function to convert.
    :type sync_func: Callable[..., T]
    :return: The asynchronous function.
    :rtype: Callable[..., Awaitable[T]]
    """

    async def async_func(*args, **kwargs) -> T:
        return await asyncio.to_thread(sync_func, *args, **kwargs)

    return async_func




from enum import Enum
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


class InstallType(Enum):
    """An enumeration representing different categories.

    :cvar CLOUD: "CLOUD"
    :vartype CLOUD: str
    :cvar ATOM: "ATOM"
    :vartype ATOM: str
    :cvar MOLECULE: "MOLECULE"
    :vartype MOLECULE: str
    :cvar BROKER: "BROKER"
    :vartype BROKER: str
    :cvar GATEWAY: "GATEWAY"
    :vartype GATEWAY: str
    """

    CLOUD = "CLOUD"
    ATOM = "ATOM"
    MOLECULE = "MOLECULE"
    BROKER = "BROKER"
    GATEWAY = "GATEWAY"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, InstallType._member_map_.values()))


@JsonMap(
    {
        "account_id": "accountId",
        "cloud_id": "cloudId",
        "duration_minutes": "durationMinutes",
        "install_type": "installType",
    }
)
class InstallerToken(BaseModel):
    """InstallerToken

    :param account_id: account_id, defaults to None
    :type account_id: str, optional
    :param cloud_id: \(For Runtime cloud installation\) A unique ID assigned by the system to the Runtime cloud., defaults to None
    :type cloud_id: str, optional
    :param created: created, defaults to None
    :type created: str, optional
    :param duration_minutes: The number of minutes for which the installer token is valid, from 30 to 1440., defaults to None
    :type duration_minutes: int, optional
    :param expiration: expiration, defaults to None
    :type expiration: str, optional
    :param install_type: -   ATOM\<br /\>-   MOLECULE\<br /\>-   CLOUD\<br /\>-   BROKER, defaults to None
    :type install_type: InstallType, optional
    :param token: token, defaults to None
    :type token: str, optional
    """

    def __init__(
        self,
        account_id: str = SENTINEL,
        cloud_id: str = SENTINEL,
        created: str = SENTINEL,
        duration_minutes: int = SENTINEL,
        expiration: str = SENTINEL,
        install_type: InstallType = SENTINEL,
        token: str = SENTINEL,
        **kwargs
    ):
        """InstallerToken

        :param account_id: account_id, defaults to None
        :type account_id: str, optional
        :param cloud_id: \(For Runtime cloud installation\) A unique ID assigned by the system to the Runtime cloud., defaults to None
        :type cloud_id: str, optional
        :param created: created, defaults to None
        :type created: str, optional
        :param duration_minutes: The number of minutes for which the installer token is valid, from 30 to 1440., defaults to None
        :type duration_minutes: int, optional
        :param expiration: expiration, defaults to None
        :type expiration: str, optional
        :param install_type: -   ATOM\<br /\>-   MOLECULE\<br /\>-   CLOUD\<br /\>-   BROKER, defaults to None
        :type install_type: InstallType, optional
        :param token: token, defaults to None
        :type token: str, optional
        """
        if account_id is not SENTINEL:
            self.account_id = account_id
        if cloud_id is not SENTINEL:
            self.cloud_id = cloud_id
        if created is not SENTINEL:
            self.created = created
        if duration_minutes is not SENTINEL:
            self.duration_minutes = duration_minutes
        if expiration is not SENTINEL:
            self.expiration = expiration
        if install_type is not SENTINEL:
            self.install_type = self._enum_matching(
                install_type, InstallType.list(), "install_type"
            )
        if token is not SENTINEL:
            self.token = token
        self._kwargs = kwargs




from typing import Awaitable, Union
from .utils.to_async import to_async
from ..environment_map_extension import EnvironmentMapExtensionService
from ...models import (
    EnvironmentMapExtension,
    EnvironmentMapExtensionBulkResponse,
    EnvironmentMapExtensionBulkRequest,
)


class EnvironmentMapExtensionServiceAsync(EnvironmentMapExtensionService):
    """
    Async Wrapper for EnvironmentMapExtensionServiceAsync
    """

    def get_environment_map_extension(
        self, id_: str
    ) -> Awaitable[Union[EnvironmentMapExtension, str]]:
        return to_async(super().get_environment_map_extension)(id_)

    def bulk_environment_map_extension(
        self, request_body: EnvironmentMapExtensionBulkRequest = None
    ) -> Awaitable[Union[EnvironmentMapExtensionBulkResponse, str]]:
        return to_async(super().bulk_environment_map_extension)(request_body)

    def execute_environment_map_extension(
        self, id_: str, request_body: EnvironmentMapExtension = None
    ) -> Awaitable[Union[EnvironmentMapExtension, str]]:
        return to_async(super().execute_environment_map_extension)(id_, request_body)




from __future__ import annotations
from typing import Union
from .utils.one_of_base_model import OneOfBaseModel
from .integration_pack_environment_attachment_simple_expression import (
    IntegrationPackEnvironmentAttachmentSimpleExpression,
)
from .integration_pack_environment_attachment_grouping_expression import (
    IntegrationPackEnvironmentAttachmentGroupingExpression,
)


class IntegrationPackEnvironmentAttachmentExpressionGuard(OneOfBaseModel):
    class_list = {
        "IntegrationPackEnvironmentAttachmentSimpleExpression": IntegrationPackEnvironmentAttachmentSimpleExpression,
        "IntegrationPackEnvironmentAttachmentGroupingExpression": IntegrationPackEnvironmentAttachmentGroupingExpression,
    }


IntegrationPackEnvironmentAttachmentExpression = Union[
    IntegrationPackEnvironmentAttachmentSimpleExpression,
    IntegrationPackEnvironmentAttachmentGroupingExpression,
]




from typing import Union
from .utils.validator import Validator
from .utils.base_service import BaseService
from ..net.transport.serializer import Serializer
from ..net.transport.api_error import ApiError
from ..net.environment.environment import Environment
from ..models.utils.cast_models import cast_models
from ..net.transport.utils import parse_xml_to_dict
from ..models import (
    ComponentEnvironmentAttachment,
    ComponentEnvironmentAttachmentQueryConfig,
    ComponentEnvironmentAttachmentQueryResponse,
)


class ComponentEnvironmentAttachmentService(BaseService):

    @cast_models
    def create_component_environment_attachment(
        self, request_body: ComponentEnvironmentAttachment = None
    ) -> Union[ComponentEnvironmentAttachment, str]:
        """Attaches a component with a specific ID to the environment with a specific ID.

        :param request_body: The request body., defaults to None
        :type request_body: ComponentEnvironmentAttachment, optional
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: The parsed response data.
        :rtype: Union[ComponentEnvironmentAttachment, str]
        """

        Validator(ComponentEnvironmentAttachment).is_optional().validate(request_body)

        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/ComponentEnvironmentAttachment",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .serialize()
            .set_method("POST")
            .set_body(request_body)
        )

        response, status, content = self.send_request(serialized_request)
        if content == "application/json":
            return ComponentEnvironmentAttachment._unmap(response)
        if content == "application/xml":
            return ComponentEnvironmentAttachment._unmap(parse_xml_to_dict(response))
        raise ApiError("Error on deserializing the response.", status, response)

    @cast_models
    def query_component_environment_attachment(
        self, request_body: ComponentEnvironmentAttachmentQueryConfig = None
    ) -> Union[ComponentEnvironmentAttachmentQueryResponse, str]:
        """For general information about the structure of QUERY filters, their sample payloads, and how to handle the paged results, refer to [Query filters](#section/Introduction/Query-filters) and [Query paging](#section/Introduction/Query-paging).

        :param request_body: The request body., defaults to None
        :type request_body: ComponentEnvironmentAttachmentQueryConfig, optional
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: The parsed response data.
        :rtype: Union[ComponentEnvironmentAttachmentQueryResponse, str]
        """

        Validator(ComponentEnvironmentAttachmentQueryConfig).is_optional().validate(
            request_body
        )

        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/ComponentEnvironmentAttachment/query",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .serialize()
            .set_method("POST")
            .set_body(request_body)
        )

        response, status, content = self.send_request(serialized_request)
        if content == "application/json":
            return ComponentEnvironmentAttachmentQueryResponse._unmap(response)
        if content == "application/xml":
            return ComponentEnvironmentAttachmentQueryResponse._unmap(parse_xml_to_dict(response))
        raise ApiError("Error on deserializing the response.", status, response)

    @cast_models
    def query_more_component_environment_attachment(
        self, request_body: str
    ) -> Union[ComponentEnvironmentAttachmentQueryResponse, str]:
        """To learn about using `queryMore`, refer to [Query paging](#section/Introduction/Query-paging).

        :param request_body: The request body.
        :type request_body: str
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: The parsed response data.
        :rtype: Union[ComponentEnvironmentAttachmentQueryResponse, str]
        """

        Validator(str).validate(request_body)

        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/ComponentEnvironmentAttachment/queryMore",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .serialize()
            .set_method("POST")
            .set_body(request_body, "text/plain")
        )

        response, status, content = self.send_request(serialized_request)
        if content == "application/json":
            return ComponentEnvironmentAttachmentQueryResponse._unmap(response)
        if content == "application/xml":
            return ComponentEnvironmentAttachmentQueryResponse._unmap(parse_xml_to_dict(response))
        raise ApiError("Error on deserializing the response.", status, response)

    @cast_models
    def delete_component_environment_attachment(self, id_: str) -> None:
        """Detaches a component from an environment where the attachment is specified by the conceptual Component Environment Attachment object ID. This ID is returned by the CREATE operation that originated the attachment and can also be obtained from a QUERY operation.

        :param id_: id_
        :type id_: str
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        """

        Validator(str).validate(id_)

        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/ComponentEnvironmentAttachment/{{id}}",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .add_path("id", id_)
            .serialize()
            .set_method("DELETE")
        )

        response, status, _ = self.send_request(serialized_request)




from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .processing_group_partner_route import ProcessingGroupPartnerRoute


@JsonMap({"partner_route": "PartnerRoute", "process_id": "processId"})
class ProcessingGroupPartnerBasedRouting(BaseModel):
    """ProcessingGroupPartnerBasedRouting

    :param partner_route: partner_route, defaults to None
    :type partner_route: List[ProcessingGroupPartnerRoute], optional
    :param process_id: process_id, defaults to None
    :type process_id: str, optional
    """

    def __init__(
        self,
        partner_route: List[ProcessingGroupPartnerRoute] = SENTINEL,
        process_id: str = SENTINEL,
        **kwargs,
    ):
        """ProcessingGroupPartnerBasedRouting

        :param partner_route: partner_route, defaults to None
        :type partner_route: List[ProcessingGroupPartnerRoute], optional
        :param process_id: process_id, defaults to None
        :type process_id: str, optional
        """
        if partner_route is not SENTINEL:
            self.partner_route = self._define_list(
                partner_route, ProcessingGroupPartnerRoute
            )
        if process_id is not SENTINEL:
            self.process_id = process_id
        self._kwargs = kwargs




from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .observability_endpoint import ObservabilityEndpoint


@JsonMap(
    {
        "observability_endpoint": "observabilityEndpoint",
        "trace_batch_size": "traceBatchSize",
        "trace_flush_interval": "traceFlushInterval",
        "trace_max_queue_size": "traceMaxQueueSize",
        "trace_timeout_seconds": "traceTimeoutSeconds",
        "override_general_observability_endpoint": "overrideGeneralObservabilityEndpoint",
        "process_filter_enabled": "processFilterEnabled",
        "process_filter_ids": "processFilterIds",
    }
)
class TraceSettings(BaseModel):
    """TraceSettings

    :param observability_endpoint: observability_endpoint
    :type observability_endpoint: ObservabilityEndpoint
    :param trace_batch_size: trace_batch_size
    :type trace_batch_size: int
    :param trace_flush_interval: trace_flush_interval
    :type trace_flush_interval: int
    :param trace_max_queue_size: trace_max_queue_size
    :type trace_max_queue_size: int
    :param trace_timeout_seconds: trace_timeout_seconds
    :type trace_timeout_seconds: int
    :param enabled: enabled, defaults to None
    :type enabled: bool, optional
    :param override_general_observability_endpoint: override_general_observability_endpoint, defaults to None
    :type override_general_observability_endpoint: bool, optional
    :param process_filter_enabled: process_filter_enabled, defaults to None
    :type process_filter_enabled: bool, optional
    :param process_filter_ids: process_filter_ids, defaults to None
    :type process_filter_ids: List[str], optional
    """

    def __init__(
        self,
        observability_endpoint: ObservabilityEndpoint,
        trace_batch_size: int,
        trace_flush_interval: int,
        trace_max_queue_size: int,
        trace_timeout_seconds: int,
        enabled: bool = SENTINEL,
        override_general_observability_endpoint: bool = SENTINEL,
        process_filter_enabled: bool = SENTINEL,
        process_filter_ids: List[str] = SENTINEL,
        **kwargs,
    ):
        """TraceSettings

        :param observability_endpoint: observability_endpoint
        :type observability_endpoint: ObservabilityEndpoint
        :param trace_batch_size: trace_batch_size
        :type trace_batch_size: int
        :param trace_flush_interval: trace_flush_interval
        :type trace_flush_interval: int
        :param trace_max_queue_size: trace_max_queue_size
        :type trace_max_queue_size: int
        :param trace_timeout_seconds: trace_timeout_seconds
        :type trace_timeout_seconds: int
        :param enabled: enabled, defaults to None
        :type enabled: bool, optional
        :param override_general_observability_endpoint: override_general_observability_endpoint, defaults to None
        :type override_general_observability_endpoint: bool, optional
        :param process_filter_enabled: process_filter_enabled, defaults to None
        :type process_filter_enabled: bool, optional
        :param process_filter_ids: process_filter_ids, defaults to None
        :type process_filter_ids: List[str], optional
        """
        self.observability_endpoint = self._define_object(
            observability_endpoint, ObservabilityEndpoint
        )
        self.trace_batch_size = trace_batch_size
        self.trace_flush_interval = trace_flush_interval
        self.trace_max_queue_size = trace_max_queue_size
        self.trace_timeout_seconds = trace_timeout_seconds
        if enabled is not SENTINEL:
            self.enabled = enabled
        if override_general_observability_endpoint is not SENTINEL:
            self.override_general_observability_endpoint = (
                override_general_observability_endpoint
            )
        if process_filter_enabled is not SENTINEL:
            self.process_filter_enabled = process_filter_enabled
        if process_filter_ids is not SENTINEL:
            self.process_filter_ids = process_filter_ids
        self._kwargs = kwargs




from .utils.json_map import JsonMap
from .utils.base_model import BaseModel


@JsonMap({})
class AtomSecurityPolicyArgumentType(BaseModel):
    """AtomSecurityPolicyArgumentType

    :param value: An argument value in a Java runtime permission.
    :type value: str
    """

    def __init__(self, value: str, **kwargs):
        """AtomSecurityPolicyArgumentType

        :param value: An argument value in a Java runtime permission.
        :type value: str
        """
        self.value = value
        self._kwargs = kwargs




from typing import Union
from .utils.validator import Validator
from .utils.base_service import BaseService
from ..net.transport.serializer import Serializer
from ..net.transport.api_error import ApiError
from ..net.environment.environment import Environment
from ..models.utils.cast_models import cast_models
from ..net.transport.utils import parse_xml_to_dict
from ..models import (
    AtomConnectorVersions,
    AtomConnectorVersionsBulkRequest,
    AtomConnectorVersionsBulkResponse,
)


class AtomConnectorVersionsService(BaseService):

    @cast_models
    def get_atom_connector_versions(
        self, id_: str
    ) -> Union[AtomConnectorVersions, str]:
        """Retrieves the properties of connectors used by the Runtime, Runtime cluster, or Runtime cloud with specified ID.

        :param id_: The ID of the Runtime, Runtime cluster, or Runtime cloud.
        :type id_: str
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: The parsed response data.
        :rtype: Union[AtomConnectorVersions, str]
        """

        Validator(str).validate(id_)

        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/AtomConnectorVersions/{{id}}",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .add_path("id", id_)
            .serialize()
            .set_method("GET")
        )

        response, status, content = self.send_request(serialized_request)
        if content == "application/json":
            return AtomConnectorVersions._unmap(response)
        if content == "application/xml":
            return AtomConnectorVersions._unmap(parse_xml_to_dict(response))
        raise ApiError("Error on deserializing the response.", status, response)

    @cast_models
    def bulk_atom_connector_versions(
        self, request_body: AtomConnectorVersionsBulkRequest = None
    ) -> Union[AtomConnectorVersionsBulkResponse, str]:
        """To learn more about `bulk`, refer to [Bulk GET operations](#section/Introduction/Bulk-GET-operations).

        :param request_body: The request body., defaults to None
        :type request_body: AtomConnectorVersionsBulkRequest, optional
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: The parsed response data.
        :rtype: Union[AtomConnectorVersionsBulkResponse, str]
        """

        Validator(AtomConnectorVersionsBulkRequest).is_optional().validate(request_body)

        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/AtomConnectorVersions/bulk",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .serialize()
            .set_method("POST")
            .set_body(request_body)
        )

        response, status, content = self.send_request(serialized_request)
        if content == "application/json":
            return AtomConnectorVersionsBulkResponse._unmap(response)
        if content == "application/xml":
            return AtomConnectorVersionsBulkResponse._unmap(parse_xml_to_dict(response))
        raise ApiError("Error on deserializing the response.", status, response)




from __future__ import annotations
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .custom_fields import CustomFields


@JsonMap(
    {
        "ack_status": "ackStatus",
        "action_type": "actionType",
        "as2_from_id": "as2FromId",
        "as2_to_id": "as2ToId",
        "atom_id": "atomId",
        "connector_name": "connectorName",
        "connector_type": "connectorType",
        "content_length": "contentLength",
        "custom_fields": "customFields",
        "date_processed": "dateProcessed",
        "document_index": "documentIndex",
        "error_message": "errorMessage",
        "execution_id": "executionId",
        "id_": "id",
        "mdn_message": "mdnMessage",
        "message_id": "messageId",
        "operation_name": "operationName",
    }
)
class As2ConnectorRecord(BaseModel):
    """As2ConnectorRecord

    :param account: The ID of the account this record was run in.
    :type account: str
    :param ack_status: The acknowledgment status — Acknowledged, Acknowledged/Errors, or Not Acknowledged., defaults to None
    :type ack_status: str, optional
    :param action_type: The type of action with which this record corresponds — Listen or Send.
    :type action_type: str
    :param as2_from_id: The arbitrary identifier that indicates the sender of the message., defaults to None
    :type as2_from_id: str, optional
    :param as2_to_id: The arbitrary identifier that indicates the recipient of the message., defaults to None
    :type as2_to_id: str, optional
    :param atom_id: The ID of the Runtime that processed this record.
    :type atom_id: str
    :param connector_name: For an AS2 Client \(Send\) operation, the value is the name of the AS2 Client connection component through which the document that corresponds to this record was sent. The value is as2sharedserver Connector for an AS2 Shared Server \(Listen\) operation, Trading Partner for an X12 trading partner Send operation, or Start for an X12 trading partner Listen operation.
    :type connector_name: str
    :param connector_type: The type of connector to which this record corresponds — as2 for AS2 Client \(Send\), as2sharedserver for AS2 Shared Server \(Listen\), or x12 for Trading Partner Send or Listen using the X12 standard.
    :type connector_type: str
    :param content_length: The length of the message in bytes., defaults to None
    :type content_length: str, optional
    :param custom_fields: custom_fields
    :type custom_fields: CustomFields
    :param date_processed: The processing date and time of this record.
    :type date_processed: str
    :param document_index: The numerical index of this record in the run., defaults to None
    :type document_index: int, optional
    :param error_message: The error message associated with this record if applicable.
    :type error_message: str
    :param execution_id: The ID of the run.
    :type execution_id: str
    :param filename: The file name of the document that corresponds to this record., defaults to None
    :type filename: str, optional
    :param id_: The ID of this record.
    :type id_: str
    :param mdn_message: The content of the Message Delivery Notification \(MDN\) message — *processed*, *processed/error*, *processed/error:* *authentication-failed*, *processed/error: decompression-failed*, or *processed/error: decryption-failed*. In a Listen action by the AS2 shared server, an MDN message generates automatically. For a Send action, generating an MDN message is an option for the processing AS2 Client operation., defaults to None
    :type mdn_message: str, optional
    :param message_id: The arbitrary identifier for the message., defaults to None
    :type message_id: str, optional
    :param mimetype: The MIME type of the message — *text/plain*, *application/binary*, *application/edifact*, *application/octet-stream*, *application/edi-x12*, or *application/xml*, defaults to None
    :type mimetype: str, optional
    :param operation_name: The name of the operation component that processed this record. The component is an AS2 Client operation in the case of a Send action or an AS2 Shared Server operation in the case of a Listen action.
    :type operation_name: str
    :param size: The size, in bytes, of the document that corresponds to this record., defaults to None
    :type size: int, optional
    :param subject: The arbitrary subject name for the message., defaults to None
    :type subject: str, optional
    :param successful: Whether the record is a success or error., defaults to None
    :type successful: bool, optional
    """

    def __init__(
        self,
        account: str,
        action_type: str,
        atom_id: str,
        connector_name: str,
        connector_type: str,
        custom_fields: CustomFields,
        date_processed: str,
        error_message: str,
        execution_id: str,
        id_: str,
        operation_name: str,
        ack_status: str = SENTINEL,
        as2_from_id: str = SENTINEL,
        as2_to_id: str = SENTINEL,
        content_length: str = SENTINEL,
        document_index: int = SENTINEL,
        filename: str = SENTINEL,
        mdn_message: str = SENTINEL,
        message_id: str = SENTINEL,
        mimetype: str = SENTINEL,
        size: int = SENTINEL,
        subject: str = SENTINEL,
        successful: bool = SENTINEL,
        **kwargs,
    ):
        """As2ConnectorRecord

        :param account: The ID of the account this record was run in.
        :type account: str
        :param ack_status: The acknowledgment status — Acknowledged, Acknowledged/Errors, or Not Acknowledged., defaults to None
        :type ack_status: str, optional
        :param action_type: The type of action with which this record corresponds — Listen or Send.
        :type action_type: str
        :param as2_from_id: The arbitrary identifier that indicates the sender of the message., defaults to None
        :type as2_from_id: str, optional
        :param as2_to_id: The arbitrary identifier that indicates the recipient of the message., defaults to None
        :type as2_to_id: str, optional
        :param atom_id: The ID of the Runtime that processed this record.
        :type atom_id: str
        :param connector_name: For an AS2 Client \(Send\) operation, the value is the name of the AS2 Client connection component through which the document that corresponds to this record was sent. The value is as2sharedserver Connector for an AS2 Shared Server \(Listen\) operation, Trading Partner for an X12 trading partner Send operation, or Start for an X12 trading partner Listen operation.
        :type connector_name: str
        :param connector_type: The type of connector to which this record corresponds — as2 for AS2 Client \(Send\), as2sharedserver for AS2 Shared Server \(Listen\), or x12 for Trading Partner Send or Listen using the X12 standard.
        :type connector_type: str
        :param content_length: The length of the message in bytes., defaults to None
        :type content_length: str, optional
        :param custom_fields: custom_fields
        :type custom_fields: CustomFields
        :param date_processed: The processing date and time of this record.
        :type date_processed: str
        :param document_index: The numerical index of this record in the run., defaults to None
        :type document_index: int, optional
        :param error_message: The error message associated with this record if applicable.
        :type error_message: str
        :param execution_id: The ID of the run.
        :type execution_id: str
        :param filename: The file name of the document that corresponds to this record., defaults to None
        :type filename: str, optional
        :param id_: The ID of this record.
        :type id_: str
        :param mdn_message: The content of the Message Delivery Notification \(MDN\) message — *processed*, *processed/error*, *processed/error:* *authentication-failed*, *processed/error: decompression-failed*, or *processed/error: decryption-failed*. In a Listen action by the AS2 shared server, an MDN message generates automatically. For a Send action, generating an MDN message is an option for the processing AS2 Client operation., defaults to None
        :type mdn_message: str, optional
        :param message_id: The arbitrary identifier for the message., defaults to None
        :type message_id: str, optional
        :param mimetype: The MIME type of the message — *text/plain*, *application/binary*, *application/edifact*, *application/octet-stream*, *application/edi-x12*, or *application/xml*, defaults to None
        :type mimetype: str, optional
        :param operation_name: The name of the operation component that processed this record. The component is an AS2 Client operation in the case of a Send action or an AS2 Shared Server operation in the case of a Listen action.
        :type operation_name: str
        :param size: The size, in bytes, of the document that corresponds to this record., defaults to None
        :type size: int, optional
        :param subject: The arbitrary subject name for the message., defaults to None
        :type subject: str, optional
        :param successful: Whether the record is a success or error., defaults to None
        :type successful: bool, optional
        """
        self.account = account
        if ack_status is not SENTINEL:
            self.ack_status = ack_status
        self.action_type = action_type
        if as2_from_id is not SENTINEL:
            self.as2_from_id = as2_from_id
        if as2_to_id is not SENTINEL:
            self.as2_to_id = as2_to_id
        self.atom_id = atom_id
        self.connector_name = connector_name
        self.connector_type = connector_type
        if content_length is not SENTINEL:
            self.content_length = content_length
        self.custom_fields = self._define_object(custom_fields, CustomFields)
        self.date_processed = date_processed
        if document_index is not SENTINEL:
            self.document_index = document_index
        self.error_message = error_message
        self.execution_id = execution_id
        if filename is not SENTINEL:
            self.filename = filename
        self.id_ = id_
        if mdn_message is not SENTINEL:
            self.mdn_message = mdn_message
        if message_id is not SENTINEL:
            self.message_id = message_id
        if mimetype is not SENTINEL:
            self.mimetype = mimetype
        self.operation_name = operation_name
        if size is not SENTINEL:
            self.size = size
        if subject is not SENTINEL:
            self.subject = subject
        if successful is not SENTINEL:
            self.successful = successful
        self._kwargs = kwargs




from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


@JsonMap({})
class SecretsManagerRefreshResponse(BaseModel):
    """SecretsManagerRefreshResponse

    :param message: message, defaults to None
    :type message: str, optional
    """

    def __init__(self, message: str = SENTINEL, **kwargs):
        """SecretsManagerRefreshResponse

        :param message: message, defaults to None
        :type message: str, optional
        """
        if message is not SENTINEL:
            self.message = message
        self._kwargs = kwargs




from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


@JsonMap({"ref_id": "refId"})
class CrossReferenceParameter(BaseModel):
    """CrossReferenceParameter

    :param index: index, defaults to None
    :type index: int, optional
    :param name: name, defaults to None
    :type name: str, optional
    :param ref_id: ref_id, defaults to None
    :type ref_id: int, optional
    """

    def __init__(
        self,
        index: int = SENTINEL,
        name: str = SENTINEL,
        ref_id: int = SENTINEL,
        **kwargs
    ):
        """CrossReferenceParameter

        :param index: index, defaults to None
        :type index: int, optional
        :param name: name, defaults to None
        :type name: str, optional
        :param ref_id: ref_id, defaults to None
        :type ref_id: int, optional
        """
        if index is not SENTINEL:
            self.index = index
        if name is not SENTINEL:
            self.name = name
        if ref_id is not SENTINEL:
            self.ref_id = ref_id
        self._kwargs = kwargs




from enum import Enum
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


class ReferencesType(Enum):
    """An enumeration representing different categories.

    :cvar DEPENDENT: "DEPENDENT"
    :vartype DEPENDENT: str
    :cvar INDEPENDENT: "INDEPENDENT"
    :vartype INDEPENDENT: str
    """

    DEPENDENT = "DEPENDENT"
    INDEPENDENT = "INDEPENDENT"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, ReferencesType._member_map_.values()))


@JsonMap(
    {
        "component_id": "componentId",
        "parent_component_id": "parentComponentId",
        "parent_version": "parentVersion",
        "type_": "type",
        "branch_id": "branchId",
    }
)
class References(BaseModel):
    """References

    :param component_id: The ID of the secondary component. The component ID is available in the Revision History dialog, which you can access from the Build page in the service., defaults to None
    :type component_id: str, optional
    :param parent_component_id: The ID of the primary component that the secondary components reference. You can use this attribute specifically in the QUERY operation. The component ID is available in the Revision History dialog, which you can access from the Build page in the service., defaults to None
    :type parent_component_id: str, optional
    :param parent_version: The revision number of the primary component. This attribute is used specifically in the QUERY operation. A component's version number is available in the Revision History dialog, which you can access from the Build page in the service., defaults to None
    :type parent_version: int, optional
    :param type_: The type of reference component.   - A value of DEPENDENT indicates that the component is included automatically in a process at packaging and deployment time.   - A value of INDEPENDENT indicates the component is standalone, and you must package and deploy it individually and manually, though you might use it in a process configuration.   For more information on component reference types, see the topic [Component References](https://help.boomi.com/docs/Atomsphere/Integration/Process%20building/int-Component_references_8d7cf9db-2716-4301-b8d8-46eb9f055999)., defaults to None
    :type type_: ReferencesType, optional
    :param branch_id: If specified, the ID of the branch on which you want to query., defaults to None
    :type branch_id: str, optional
    """

    def __init__(
        self,
        component_id: str = SENTINEL,
        parent_component_id: str = SENTINEL,
        parent_version: int = SENTINEL,
        type_: ReferencesType = SENTINEL,
        branch_id: str = SENTINEL,
        **kwargs
    ):
        """References

        :param component_id: The ID of the secondary component. The component ID is available in the Revision History dialog, which you can access from the Build page in the service., defaults to None
        :type component_id: str, optional
        :param parent_component_id: The ID of the primary component that the secondary components reference. You can use this attribute specifically in the QUERY operation. The component ID is available in the Revision History dialog, which you can access from the Build page in the service., defaults to None
        :type parent_component_id: str, optional
        :param parent_version: The revision number of the primary component. This attribute is used specifically in the QUERY operation. A component's version number is available in the Revision History dialog, which you can access from the Build page in the service., defaults to None
        :type parent_version: int, optional
        :param type_: The type of reference component.   - A value of DEPENDENT indicates that the component is included automatically in a process at packaging and deployment time.   - A value of INDEPENDENT indicates the component is standalone, and you must package and deploy it individually and manually, though you might use it in a process configuration.   For more information on component reference types, see the topic [Component References](https://help.boomi.com/docs/Atomsphere/Integration/Process%20building/int-Component_references_8d7cf9db-2716-4301-b8d8-46eb9f055999)., defaults to None
        :type type_: ReferencesType, optional
        :param branch_id: If specified, the ID of the branch on which you want to query., defaults to None
        :type branch_id: str, optional
        """
        if component_id is not SENTINEL:
            self.component_id = component_id
        if parent_component_id is not SENTINEL:
            self.parent_component_id = parent_component_id
        if parent_version is not SENTINEL:
            self.parent_version = parent_version
        if type_ is not SENTINEL:
            self.type_ = self._enum_matching(type_, ReferencesType.list(), "type_")
        if branch_id is not SENTINEL:
            self.branch_id = branch_id
        self._kwargs = kwargs




from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


@JsonMap(
    {
        "account_id": "accountID",
        "atom_id": "atomID",
        "atom_name": "atomName",
        "elapsed_time": "elapsedTime",
        "elapsed_var_sum": "elapsedVarSum",
        "execution_count": "executionCount",
        "inbound_doc_count": "inboundDocCount",
        "inbound_doc_size": "inboundDocSize",
        "launch_elapsed_time": "launchElapsedTime",
        "launcher_id": "launcherID",
        "max_elapsed_time": "maxElapsedTime",
        "outbound_doc_count": "outboundDocCount",
        "outbound_doc_size": "outboundDocSize",
        "process_id": "processID",
        "process_name": "processName",
        "report_key": "reportKey",
        "return_doc_count": "returnDocCount",
        "return_doc_size": "returnDocSize",
        "time_block": "timeBlock",
    }
)
class ExecutionSummaryRecord(BaseModel):
    """ExecutionSummaryRecord

    :param account_id: The account under which the processes ran., defaults to None
    :type account_id: str, optional
    :param atom_id: The component ID of the Runtime on which the processes ran., defaults to None
    :type atom_id: str, optional
    :param atom_name: The name of the Runtime on which the runs occurred., defaults to None
    :type atom_name: str, optional
    :param elapsed_time: The aggregate elapsed processing time, in milliseconds, of the runs that occurred., defaults to None
    :type elapsed_time: int, optional
    :param elapsed_var_sum: A composite value enabling computation of the standard deviation of elapsed run time for the processes that occurred using the [parallel algorithm](http://en.wikipedia.org/wiki/Algorithms_for_calculating_variance#Parallel_algorithm)., defaults to None
    :type elapsed_var_sum: float, optional
    :param execution_count: The number of runs that occurred., defaults to None
    :type execution_count: int, optional
    :param inbound_doc_count: The aggregate number of processed inbound documents for the runs that occurred., defaults to None
    :type inbound_doc_count: int, optional
    :param inbound_doc_size: The aggregate size, in bytes, of the processed inbound documents for the runs that occurred., defaults to None
    :type inbound_doc_size: int, optional
    :param launch_elapsed_time: The aggregate elapsed wait time, in milliseconds, before the start of processing for the runs that occurred., defaults to None
    :type launch_elapsed_time: int, optional
    :param launcher_id: The API Service component that kicks off the run.\<br /\> **Note:** The Runtime must have the **API Type** set to **Advanced** on the **Shared Web Server** tab of **Runtime Management** to specify launcherId., defaults to None
    :type launcher_id: str, optional
    :param max_elapsed_time: The time, in milliseconds, it took for the most time-consuming run that occurred., defaults to None
    :type max_elapsed_time: int, optional
    :param outbound_doc_count: The aggregate number of processed outbound documents for the runs that occurred., defaults to None
    :type outbound_doc_count: int, optional
    :param outbound_doc_size: The aggregate size, in bytes, of the processed outbound documents for the runs that occurred., defaults to None
    :type outbound_doc_size: int, optional
    :param process_id: The component ID of the processes that ran., defaults to None
    :type process_id: str, optional
    :param process_name: The name of the process that was run., defaults to None
    :type process_name: str, optional
    :param report_key: The web service user that authenticated to make the run request. \<br /\>**Note:** For Runtimes with an Authentication Type of External Provider, the reportKey is the API Key. Otherwise, it is the specified user name., defaults to None
    :type report_key: str, optional
    :param return_doc_count: The aggregate number of resulting documents for the runs that occurred., defaults to None
    :type return_doc_count: int, optional
    :param return_doc_size: The aggregate size, in bytes, of resulting documents for the runs that occurred., defaults to None
    :type return_doc_size: int, optional
    :param status: The status of the runs. Allowed values include COMPLETE, COMPLETE\_WARN, ERROR., defaults to None
    :type status: str, optional
    :param time_block: The start time of the represented time block., defaults to None
    :type time_block: str, optional
    """

    def __init__(
        self,
        account_id: str = SENTINEL,
        atom_id: str = SENTINEL,
        atom_name: str = SENTINEL,
        elapsed_time: int = SENTINEL,
        elapsed_var_sum: float = SENTINEL,
        execution_count: int = SENTINEL,
        inbound_doc_count: int = SENTINEL,
        inbound_doc_size: int = SENTINEL,
        launch_elapsed_time: int = SENTINEL,
        launcher_id: str = SENTINEL,
        max_elapsed_time: int = SENTINEL,
        outbound_doc_count: int = SENTINEL,
        outbound_doc_size: int = SENTINEL,
        process_id: str = SENTINEL,
        process_name: str = SENTINEL,
        report_key: str = SENTINEL,
        return_doc_count: int = SENTINEL,
        return_doc_size: int = SENTINEL,
        status: str = SENTINEL,
        time_block: str = SENTINEL,
        **kwargs
    ):
        """ExecutionSummaryRecord

        :param account_id: The account under which the processes ran., defaults to None
        :type account_id: str, optional
        :param atom_id: The component ID of the Runtime on which the processes ran., defaults to None
        :type atom_id: str, optional
        :param atom_name: The name of the Runtime on which the runs occurred., defaults to None
        :type atom_name: str, optional
        :param elapsed_time: The aggregate elapsed processing time, in milliseconds, of the runs that occurred., defaults to None
        :type elapsed_time: int, optional
        :param elapsed_var_sum: A composite value enabling computation of the standard deviation of elapsed run time for the processes that occurred using the [parallel algorithm](http://en.wikipedia.org/wiki/Algorithms_for_calculating_variance#Parallel_algorithm)., defaults to None
        :type elapsed_var_sum: float, optional
        :param execution_count: The number of runs that occurred., defaults to None
        :type execution_count: int, optional
        :param inbound_doc_count: The aggregate number of processed inbound documents for the runs that occurred., defaults to None
        :type inbound_doc_count: int, optional
        :param inbound_doc_size: The aggregate size, in bytes, of the processed inbound documents for the runs that occurred., defaults to None
        :type inbound_doc_size: int, optional
        :param launch_elapsed_time: The aggregate elapsed wait time, in milliseconds, before the start of processing for the runs that occurred., defaults to None
        :type launch_elapsed_time: int, optional
        :param launcher_id: The API Service component that kicks off the run.\<br /\> **Note:** The Runtime must have the **API Type** set to **Advanced** on the **Shared Web Server** tab of **Runtime Management** to specify launcherId., defaults to None
        :type launcher_id: str, optional
        :param max_elapsed_time: The time, in milliseconds, it took for the most time-consuming run that occurred., defaults to None
        :type max_elapsed_time: int, optional
        :param outbound_doc_count: The aggregate number of processed outbound documents for the runs that occurred., defaults to None
        :type outbound_doc_count: int, optional
        :param outbound_doc_size: The aggregate size, in bytes, of the processed outbound documents for the runs that occurred., defaults to None
        :type outbound_doc_size: int, optional
        :param process_id: The component ID of the processes that ran., defaults to None
        :type process_id: str, optional
        :param process_name: The name of the process that was run., defaults to None
        :type process_name: str, optional
        :param report_key: The web service user that authenticated to make the run request. \<br /\>**Note:** For Runtimes with an Authentication Type of External Provider, the reportKey is the API Key. Otherwise, it is the specified user name., defaults to None
        :type report_key: str, optional
        :param return_doc_count: The aggregate number of resulting documents for the runs that occurred., defaults to None
        :type return_doc_count: int, optional
        :param return_doc_size: The aggregate size, in bytes, of resulting documents for the runs that occurred., defaults to None
        :type return_doc_size: int, optional
        :param status: The status of the runs. Allowed values include COMPLETE, COMPLETE\_WARN, ERROR., defaults to None
        :type status: str, optional
        :param time_block: The start time of the represented time block., defaults to None
        :type time_block: str, optional
        """
        if account_id is not SENTINEL:
            self.account_id = account_id
        if atom_id is not SENTINEL:
            self.atom_id = atom_id
        if atom_name is not SENTINEL:
            self.atom_name = atom_name
        if elapsed_time is not SENTINEL:
            self.elapsed_time = elapsed_time
        if elapsed_var_sum is not SENTINEL:
            self.elapsed_var_sum = elapsed_var_sum
        if execution_count is not SENTINEL:
            self.execution_count = execution_count
        if inbound_doc_count is not SENTINEL:
            self.inbound_doc_count = inbound_doc_count
        if inbound_doc_size is not SENTINEL:
            self.inbound_doc_size = inbound_doc_size
        if launch_elapsed_time is not SENTINEL:
            self.launch_elapsed_time = launch_elapsed_time
        if launcher_id is not SENTINEL:
            self.launcher_id = launcher_id
        if max_elapsed_time is not SENTINEL:
            self.max_elapsed_time = max_elapsed_time
        if outbound_doc_count is not SENTINEL:
            self.outbound_doc_count = outbound_doc_count
        if outbound_doc_size is not SENTINEL:
            self.outbound_doc_size = outbound_doc_size
        if process_id is not SENTINEL:
            self.process_id = process_id
        if process_name is not SENTINEL:
            self.process_name = process_name
        if report_key is not SENTINEL:
            self.report_key = report_key
        if return_doc_count is not SENTINEL:
            self.return_doc_count = return_doc_count
        if return_doc_size is not SENTINEL:
            self.return_doc_size = return_doc_size
        if status is not SENTINEL:
            self.status = status
        if time_block is not SENTINEL:
            self.time_block = time_block
        self._kwargs = kwargs




from __future__ import annotations
from enum import Enum
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .release_packaged_components import ReleasePackagedComponents


class ReleaseIntegrationPackInstallationType(Enum):
    """An enumeration representing different categories.

    :cvar SINGLE: "SINGLE"
    :vartype SINGLE: str
    :cvar MULTI: "MULTI"
    :vartype MULTI: str
    """

    SINGLE = "SINGLE"
    MULTI = "MULTI"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(
                lambda x: x.value,
                ReleaseIntegrationPackInstallationType._member_map_.values(),
            )
        )


class ReleaseIntegrationPackReleaseSchedule(Enum):
    """An enumeration representing different categories.

    :cvar IMMEDIATELY: "IMMEDIATELY"
    :vartype IMMEDIATELY: str
    :cvar RELEASEONSPECIFIEDDATE: "RELEASE_ON_SPECIFIED_DATE"
    :vartype RELEASEONSPECIFIEDDATE: str
    """

    IMMEDIATELY = "IMMEDIATELY"
    RELEASEONSPECIFIEDDATE = "RELEASE_ON_SPECIFIED_DATE"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(
                lambda x: x.value,
                ReleaseIntegrationPackReleaseSchedule._member_map_.values(),
            )
        )


@JsonMap(
    {
        "release_packaged_components": "ReleasePackagedComponents",
        "id_": "id",
        "installation_type": "installationType",
        "release_on_date": "releaseOnDate",
        "release_schedule": "releaseSchedule",
        "release_status_url": "releaseStatusUrl",
        "request_id": "requestId",
    }
)
class ReleaseIntegrationPack(BaseModel):
    """ReleaseIntegrationPack

    :param release_packaged_components: release_packaged_components, defaults to None
    :type release_packaged_components: ReleasePackagedComponents, optional
    :param id_: The ID of the integration pack., defaults to None
    :type id_: str, optional
    :param installation_type: The type of integration pack. Possible values: - SINGLE — single attachment  - MULTI — multiple attachment, defaults to None
    :type installation_type: ReleaseIntegrationPackInstallationType, optional
    :param name: The name of the integration pack., defaults to None
    :type name: str, optional
    :param release_on_date: Date for future release of integration pack.  Date Format: yyyy-MM-dd, defaults to None
    :type release_on_date: str, optional
    :param release_schedule: Specify the type of release schedule for the integration pack. Possible values: - IMMEDIATELY — for immediate release - RELEASE_ON_SPECIFIED_DATE — for future release, defaults to None
    :type release_schedule: ReleaseIntegrationPackReleaseSchedule, optional
    :param release_status_url: The complete endpoint URL used to make a second call to the ReleaseIntegrationPackStatus object.  It is provided for your convenience in the `releaseStatusUrl` field of the initial POST response., defaults to None
    :type release_status_url: str, optional
    :param request_id: A unique ID assigned by the system to the integration pack release request., defaults to None
    :type request_id: str, optional
    """

    def __init__(
        self,
        release_packaged_components: ReleasePackagedComponents = SENTINEL,
        id_: str = SENTINEL,
        installation_type: ReleaseIntegrationPackInstallationType = SENTINEL,
        name: str = SENTINEL,
        release_on_date: str = SENTINEL,
        release_schedule: ReleaseIntegrationPackReleaseSchedule = SENTINEL,
        release_status_url: str = SENTINEL,
        request_id: str = SENTINEL,
        **kwargs,
    ):
        """ReleaseIntegrationPack

        :param release_packaged_components: release_packaged_components, defaults to None
        :type release_packaged_components: ReleasePackagedComponents, optional
        :param id_: The ID of the integration pack., defaults to None
        :type id_: str, optional
        :param installation_type: The type of integration pack. Possible values: - SINGLE — single attachment  - MULTI — multiple attachment, defaults to None
        :type installation_type: ReleaseIntegrationPackInstallationType, optional
        :param name: The name of the integration pack., defaults to None
        :type name: str, optional
        :param release_on_date: Date for future release of integration pack.  Date Format: yyyy-MM-dd, defaults to None
        :type release_on_date: str, optional
        :param release_schedule: Specify the type of release schedule for the integration pack. Possible values: - IMMEDIATELY — for immediate release - RELEASE_ON_SPECIFIED_DATE — for future release, defaults to None
        :type release_schedule: ReleaseIntegrationPackReleaseSchedule, optional
        :param release_status_url: The complete endpoint URL used to make a second call to the ReleaseIntegrationPackStatus object.  It is provided for your convenience in the `releaseStatusUrl` field of the initial POST response., defaults to None
        :type release_status_url: str, optional
        :param request_id: A unique ID assigned by the system to the integration pack release request., defaults to None
        :type request_id: str, optional
        """
        if release_packaged_components is not SENTINEL:
            self.release_packaged_components = self._define_object(
                release_packaged_components, ReleasePackagedComponents
            )
        if id_ is not SENTINEL:
            self.id_ = id_
        if installation_type is not SENTINEL:
            self.installation_type = self._enum_matching(
                installation_type,
                ReleaseIntegrationPackInstallationType.list(),
                "installation_type",
            )
        if name is not SENTINEL:
            self.name = name
        if release_on_date is not SENTINEL:
            self.release_on_date = release_on_date
        if release_schedule is not SENTINEL:
            self.release_schedule = self._enum_matching(
                release_schedule,
                ReleaseIntegrationPackReleaseSchedule.list(),
                "release_schedule",
            )
        if release_status_url is not SENTINEL:
            self.release_status_url = release_status_url
        if request_id is not SENTINEL:
            self.request_id = request_id
        self._kwargs = kwargs




from typing import Awaitable, Union
from .utils.to_async import to_async
from ..deployed_expired_certificate import DeployedExpiredCertificateService
from ...models import (
    DeployedExpiredCertificateQueryResponse,
    DeployedExpiredCertificateQueryConfig,
)


class DeployedExpiredCertificateServiceAsync(DeployedExpiredCertificateService):
    """
    Async Wrapper for DeployedExpiredCertificateServiceAsync
    """

    def query_deployed_expired_certificate(
        self, request_body: DeployedExpiredCertificateQueryConfig = None
    ) -> Awaitable[Union[DeployedExpiredCertificateQueryResponse, str]]:
        return to_async(super().query_deployed_expired_certificate)(request_body)

    def query_more_deployed_expired_certificate(
        self, request_body: str
    ) -> Awaitable[Union[DeployedExpiredCertificateQueryResponse, str]]:
        return to_async(super().query_more_deployed_expired_certificate)(request_body)




from __future__ import annotations
from typing import Union
from .utils.one_of_base_model import OneOfBaseModel
from .odette_connector_record_simple_expression import (
    OdetteConnectorRecordSimpleExpression,
)
from .odette_connector_record_grouping_expression import (
    OdetteConnectorRecordGroupingExpression,
)


class OdetteConnectorRecordExpressionGuard(OneOfBaseModel):
    class_list = {
        "OdetteConnectorRecordSimpleExpression": OdetteConnectorRecordSimpleExpression,
        "OdetteConnectorRecordGroupingExpression": OdetteConnectorRecordGroupingExpression,
    }


OdetteConnectorRecordExpression = Union[
    OdetteConnectorRecordSimpleExpression, OdetteConnectorRecordGroupingExpression
]




from enum import Enum
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


class SftpProxySettingsType(Enum):
    """An enumeration representing different categories.

    :cvar ATOM: "ATOM"
    :vartype ATOM: str
    :cvar HTTP: "HTTP"
    :vartype HTTP: str
    :cvar SOCKS4: "SOCKS4"
    :vartype SOCKS4: str
    :cvar SOCKS5: "SOCKS5"
    :vartype SOCKS5: str
    """

    ATOM = "ATOM"
    HTTP = "HTTP"
    SOCKS4 = "SOCKS4"
    SOCKS5 = "SOCKS5"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, SftpProxySettingsType._member_map_.values()))


@JsonMap({"proxy_enabled": "proxyEnabled", "type_": "type"})
class SftpProxySettings(BaseModel):
    """SftpProxySettings

    :param host: host
    :type host: str
    :param password: password
    :type password: str
    :param port: port
    :type port: int
    :param proxy_enabled: proxy_enabled, defaults to None
    :type proxy_enabled: bool, optional
    :param type_: type_, defaults to None
    :type type_: SftpProxySettingsType, optional
    :param user: user
    :type user: str
    """

    def __init__(
        self,
        host: str,
        password: str,
        port: int,
        user: str,
        proxy_enabled: bool = SENTINEL,
        type_: SftpProxySettingsType = SENTINEL,
        **kwargs
    ):
        """SftpProxySettings

        :param host: host
        :type host: str
        :param password: password
        :type password: str
        :param port: port
        :type port: int
        :param proxy_enabled: proxy_enabled, defaults to None
        :type proxy_enabled: bool, optional
        :param type_: type_, defaults to None
        :type type_: SftpProxySettingsType, optional
        :param user: user
        :type user: str
        """
        self.host = host
        self.password = password
        self.port = port
        if proxy_enabled is not SENTINEL:
            self.proxy_enabled = proxy_enabled
        if type_ is not SENTINEL:
            self.type_ = self._enum_matching(
                type_, SftpProxySettingsType.list(), "type_"
            )
        self.user = user
        self._kwargs = kwargs




from __future__ import annotations
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .custom_fields import CustomFields


@JsonMap(
    {
        "pip_code": "PIPCode",
        "pip_version": "PIPVersion",
        "ack_report": "ackReport",
        "ack_status": "ackStatus",
        "action_instance_identifier": "actionInstanceIdentifier",
        "action_type": "actionType",
        "atom_id": "atomId",
        "attempt_count": "attemptCount",
        "business_activity_identifier": "businessActivityIdentifier",
        "connector_name": "connectorName",
        "connector_type": "connectorType",
        "custom_fields": "customFields",
        "date_processed": "dateProcessed",
        "date_time": "dateTime",
        "document_index": "documentIndex",
        "error_message": "errorMessage",
        "execution_id": "executionId",
        "framework_version": "frameworkVersion",
        "from_global_business_service_code": "fromGlobalBusinessServiceCode",
        "from_global_partner_role_classification_code": "fromGlobalPartnerRoleClassificationCode",
        "global_business_action_code": "globalBusinessActionCode",
        "global_document_function_code": "globalDocumentFunctionCode",
        "global_process_code": "globalProcessCode",
        "global_usage_code": "globalUsageCode",
        "id_": "id",
        "in_response_to_global_business_action_code": "inResponseToGlobalBusinessActionCode",
        "in_response_to_instance_identifier": "inResponseToInstanceIdentifier",
        "is_secure_transport_required": "isSecureTransportRequired",
        "known_initiating_partner_id": "knownInitiatingPartnerID",
        "operation_name": "operationName",
        "outbound_validation_report": "outboundValidationReport",
        "outbound_validation_status": "outboundValidationStatus",
        "process_instance_identifier": "processInstanceIdentifier",
        "receiver_id": "receiverID",
        "sender_id": "senderID",
        "time_to_acknowledge_acceptance": "timeToAcknowledgeAcceptance",
        "time_to_acknowledge_receipt": "timeToAcknowledgeReceipt",
        "time_to_perform": "timeToPerform",
        "to_global_business_service_code": "toGlobalBusinessServiceCode",
        "to_global_partner_role_classification_code": "toGlobalPartnerRoleClassificationCode",
        "transaction_instance_identifier": "transactionInstanceIdentifier",
    }
)
class RosettaNetConnectorRecord(BaseModel):
    """RosettaNetConnectorRecord

    :param pip_code: The Partner Interface Process \(PIP\) code., defaults to None
    :type pip_code: str, optional
    :param pip_version: The unique version number of the PIP document., defaults to None
    :type pip_version: str, optional
    :param account: The ID of the account in which you ran the record.
    :type account: str
    :param ack_report: The acknowledgment report., defaults to None
    :type ack_report: str, optional
    :param ack_status: The acknowledgment status — either Acknowledged, Error - No Acknowledgement Returned, Exception, or Not Expected., defaults to None
    :type ack_status: str, optional
    :param action_instance_identifier: The unique identifier for the action instance., defaults to None
    :type action_instance_identifier: str, optional
    :param action_type: The type of action with which this record corresponds — Send for an outbound interchange, Get for an inbound interchange using the Disk, FTP, or SFTP communication method, or Listen for an inbound interchange using the AS2 or HTTP communication method.
    :type action_type: str
    :param atom_id: The ID of the Runtime that processed this record.
    :type atom_id: str
    :param attempt_count: The number of times you attempted the transaction — for example, 1 for the first attempt. For a RosettaNet 2.0 interchange, the value is N/A., defaults to None
    :type attempt_count: str, optional
    :param business_activity_identifier: The code identifying the business activity within the PIP., defaults to None
    :type business_activity_identifier: str, optional
    :param connector_name: The value is Trading Partner** for a RosettaNet trading partner Send operation, or Start for a RosettaNet trading partner Listen operation.
    :type connector_name: str
    :param connector_type: *rosettanet* is the connector type for any record.
    :type connector_type: str
    :param custom_fields: custom_fields
    :type custom_fields: CustomFields
    :param date_processed: The processing date and time of this record. The format is *yyyy-MM-dd'T'HH:mm:ss'Z'*, — for example, 2016-01-31T15:32:00Z.
    :type date_processed: str
    :param date_time: The date and time of the message delivery., defaults to None
    :type date_time: str, optional
    :param document_index: The numerical index of this record in the run., defaults to None
    :type document_index: int, optional
    :param error_message: Any error message associated with this record. This field is omitted for a successful interchange.
    :type error_message: str
    :param execution_id: The ID of the run.
    :type execution_id: str
    :param framework_version: The version of the RosettaNet Implementation Framework — *1.1* or *2.0* — that specifies the structure of the document represented by this record., defaults to None
    :type framework_version: str, optional
    :param from_global_business_service_code: The code identifying the sending trading partner’s business service network component., defaults to None
    :type from_global_business_service_code: str, optional
    :param from_global_partner_role_classification_code: The code identifying the role the sending trading partner plays in the PIP., defaults to None
    :type from_global_partner_role_classification_code: str, optional
    :param global_business_action_code: The business action., defaults to None
    :type global_business_action_code: str, optional
    :param global_document_function_code: Specifies whether the record represents a Request, Response, or neither; in the latter case the value is N/A. For a RosettaNet 2.0 interchange the value is N/A., defaults to None
    :type global_document_function_code: str, optional
    :param global_process_code: The name of the PIP specification document. For a RosettaNet 2.0 interchange, the value is *N/A*., defaults to None
    :type global_process_code: str, optional
    :param global_usage_code: Indicates whether the record is a Production or Test mode interchange., defaults to None
    :type global_usage_code: str, optional
    :param id_: The ID of this record.
    :type id_: str
    :param in_response_to_global_business_action_code: If the document is a response, the business action of the corresponding request., defaults to None
    :type in_response_to_global_business_action_code: str, optional
    :param in_response_to_instance_identifier: If the document is a response, the action instance identifier of the corresponding request., defaults to None
    :type in_response_to_instance_identifier: str, optional
    :param is_secure_transport_required: Yes indicates transporting the document from the next hub securely. No suggests the document does not need transporting from the next hub uniquely. For a RosettaNet 1.1 interchange, the value is N/A., defaults to None
    :type is_secure_transport_required: str, optional
    :param known_initiating_partner_id: The unique identifier for the known initiating trading partner. The value is sourced by the document property Known Initiating Partner Global Business Identifier in the process. If this document property is not set in the process, the field’s value is the same as the senderID., defaults to None
    :type known_initiating_partner_id: str, optional
    :param operation_name: The name of the operation component that processed the record.
    :type operation_name: str
    :param outbound_validation_report: The outbound validation report. This report contains descriptions of errors present in the outbound message. If you did not select the outbound validation option in the sending trading partner, the value is N/A. Inbound messages omit this field., defaults to None
    :type outbound_validation_report: str, optional
    :param outbound_validation_status: The outbound validation status — is either Success, Error-Message, or N/A. For an outbound message for which you do not select the outbound validation option in the sending trading partner, the value is N/A. Inbound messages omit this field., defaults to None
    :type outbound_validation_status: str, optional
    :param process_instance_identifier: The unique identifier for the process instance. For a RosettaNet 2.0 interchange, the value is N/A., defaults to None
    :type process_instance_identifier: str, optional
    :param receiver_id: The unique identifier for the receiving trading partner., defaults to None
    :type receiver_id: str, optional
    :param sender_id: The unique identifier for the sending trading partner., defaults to None
    :type sender_id: str, optional
    :param size: The size, in bytes, of the document that corresponds to this record., defaults to None
    :type size: int, optional
    :param successful: Whether the record is a success or error., defaults to None
    :type successful: bool, optional
    :param time_to_acknowledge_acceptance: The length of the time-out period, in the format *CCYYMMDDThhmmss.sss*, for acknowledging acceptance of a message. For a RosettaNet 2.0 interchange, the value is N/A., defaults to None
    :type time_to_acknowledge_acceptance: str, optional
    :param time_to_acknowledge_receipt: The length of the time-out period, in the format *CCYYMMDDThhmmss.sss*, for acknowledging receipt of a message. For a RosettaNet 2.0 interchange, the value is N/A., defaults to None
    :type time_to_acknowledge_receipt: str, optional
    :param time_to_perform: The maximum length of the time period, in the format *CCYYMMDDThhmmss.sss*, that an initiating business activity waits for a responding activity to process a document. For a RosettaNet 2.0 interchange, the value is N/A., defaults to None
    :type time_to_perform: str, optional
    :param to_global_business_service_code: The code identifying the receiving trading partner’s business service network component., defaults to None
    :type to_global_business_service_code: str, optional
    :param to_global_partner_role_classification_code: The code identifying the role the receiving trading partner plays in the PIP., defaults to None
    :type to_global_partner_role_classification_code: str, optional
    :param transaction_instance_identifier: The unique identifier for the transaction instance., defaults to None
    :type transaction_instance_identifier: str, optional
    """

    def __init__(
        self,
        account: str,
        action_type: str,
        atom_id: str,
        connector_name: str,
        connector_type: str,
        custom_fields: CustomFields,
        date_processed: str,
        error_message: str,
        execution_id: str,
        id_: str,
        operation_name: str,
        pip_code: str = SENTINEL,
        pip_version: str = SENTINEL,
        ack_report: str = SENTINEL,
        ack_status: str = SENTINEL,
        action_instance_identifier: str = SENTINEL,
        attempt_count: str = SENTINEL,
        business_activity_identifier: str = SENTINEL,
        date_time: str = SENTINEL,
        document_index: int = SENTINEL,
        framework_version: str = SENTINEL,
        from_global_business_service_code: str = SENTINEL,
        from_global_partner_role_classification_code: str = SENTINEL,
        global_business_action_code: str = SENTINEL,
        global_document_function_code: str = SENTINEL,
        global_process_code: str = SENTINEL,
        global_usage_code: str = SENTINEL,
        in_response_to_global_business_action_code: str = SENTINEL,
        in_response_to_instance_identifier: str = SENTINEL,
        is_secure_transport_required: str = SENTINEL,
        known_initiating_partner_id: str = SENTINEL,
        outbound_validation_report: str = SENTINEL,
        outbound_validation_status: str = SENTINEL,
        process_instance_identifier: str = SENTINEL,
        receiver_id: str = SENTINEL,
        sender_id: str = SENTINEL,
        size: int = SENTINEL,
        successful: bool = SENTINEL,
        time_to_acknowledge_acceptance: str = SENTINEL,
        time_to_acknowledge_receipt: str = SENTINEL,
        time_to_perform: str = SENTINEL,
        to_global_business_service_code: str = SENTINEL,
        to_global_partner_role_classification_code: str = SENTINEL,
        transaction_instance_identifier: str = SENTINEL,
        **kwargs,
    ):
        """RosettaNetConnectorRecord

        :param pip_code: The Partner Interface Process \(PIP\) code., defaults to None
        :type pip_code: str, optional
        :param pip_version: The unique version number of the PIP document., defaults to None
        :type pip_version: str, optional
        :param account: The ID of the account in which you ran the record.
        :type account: str
        :param ack_report: The acknowledgment report., defaults to None
        :type ack_report: str, optional
        :param ack_status: The acknowledgment status — either Acknowledged, Error - No Acknowledgement Returned, Exception, or Not Expected., defaults to None
        :type ack_status: str, optional
        :param action_instance_identifier: The unique identifier for the action instance., defaults to None
        :type action_instance_identifier: str, optional
        :param action_type: The type of action with which this record corresponds — Send for an outbound interchange, Get for an inbound interchange using the Disk, FTP, or SFTP communication method, or Listen for an inbound interchange using the AS2 or HTTP communication method.
        :type action_type: str
        :param atom_id: The ID of the Runtime that processed this record.
        :type atom_id: str
        :param attempt_count: The number of times you attempted the transaction — for example, 1 for the first attempt. For a RosettaNet 2.0 interchange, the value is N/A., defaults to None
        :type attempt_count: str, optional
        :param business_activity_identifier: The code identifying the business activity within the PIP., defaults to None
        :type business_activity_identifier: str, optional
        :param connector_name: The value is Trading Partner** for a RosettaNet trading partner Send operation, or Start for a RosettaNet trading partner Listen operation.
        :type connector_name: str
        :param connector_type: *rosettanet* is the connector type for any record.
        :type connector_type: str
        :param custom_fields: custom_fields
        :type custom_fields: CustomFields
        :param date_processed: The processing date and time of this record. The format is *yyyy-MM-dd'T'HH:mm:ss'Z'*, — for example, 2016-01-31T15:32:00Z.
        :type date_processed: str
        :param date_time: The date and time of the message delivery., defaults to None
        :type date_time: str, optional
        :param document_index: The numerical index of this record in the run., defaults to None
        :type document_index: int, optional
        :param error_message: Any error message associated with this record. This field is omitted for a successful interchange.
        :type error_message: str
        :param execution_id: The ID of the run.
        :type execution_id: str
        :param framework_version: The version of the RosettaNet Implementation Framework — *1.1* or *2.0* — that specifies the structure of the document represented by this record., defaults to None
        :type framework_version: str, optional
        :param from_global_business_service_code: The code identifying the sending trading partner’s business service network component., defaults to None
        :type from_global_business_service_code: str, optional
        :param from_global_partner_role_classification_code: The code identifying the role the sending trading partner plays in the PIP., defaults to None
        :type from_global_partner_role_classification_code: str, optional
        :param global_business_action_code: The business action., defaults to None
        :type global_business_action_code: str, optional
        :param global_document_function_code: Specifies whether the record represents a Request, Response, or neither; in the latter case the value is N/A. For a RosettaNet 2.0 interchange the value is N/A., defaults to None
        :type global_document_function_code: str, optional
        :param global_process_code: The name of the PIP specification document. For a RosettaNet 2.0 interchange, the value is *N/A*., defaults to None
        :type global_process_code: str, optional
        :param global_usage_code: Indicates whether the record is a Production or Test mode interchange., defaults to None
        :type global_usage_code: str, optional
        :param id_: The ID of this record.
        :type id_: str
        :param in_response_to_global_business_action_code: If the document is a response, the business action of the corresponding request., defaults to None
        :type in_response_to_global_business_action_code: str, optional
        :param in_response_to_instance_identifier: If the document is a response, the action instance identifier of the corresponding request., defaults to None
        :type in_response_to_instance_identifier: str, optional
        :param is_secure_transport_required: Yes indicates transporting the document from the next hub securely. No suggests the document does not need transporting from the next hub uniquely. For a RosettaNet 1.1 interchange, the value is N/A., defaults to None
        :type is_secure_transport_required: str, optional
        :param known_initiating_partner_id: The unique identifier for the known initiating trading partner. The value is sourced by the document property Known Initiating Partner Global Business Identifier in the process. If this document property is not set in the process, the field’s value is the same as the senderID., defaults to None
        :type known_initiating_partner_id: str, optional
        :param operation_name: The name of the operation component that processed the record.
        :type operation_name: str
        :param outbound_validation_report: The outbound validation report. This report contains descriptions of errors present in the outbound message. If you did not select the outbound validation option in the sending trading partner, the value is N/A. Inbound messages omit this field., defaults to None
        :type outbound_validation_report: str, optional
        :param outbound_validation_status: The outbound validation status — is either Success, Error-Message, or N/A. For an outbound message for which you do not select the outbound validation option in the sending trading partner, the value is N/A. Inbound messages omit this field., defaults to None
        :type outbound_validation_status: str, optional
        :param process_instance_identifier: The unique identifier for the process instance. For a RosettaNet 2.0 interchange, the value is N/A., defaults to None
        :type process_instance_identifier: str, optional
        :param receiver_id: The unique identifier for the receiving trading partner., defaults to None
        :type receiver_id: str, optional
        :param sender_id: The unique identifier for the sending trading partner., defaults to None
        :type sender_id: str, optional
        :param size: The size, in bytes, of the document that corresponds to this record., defaults to None
        :type size: int, optional
        :param successful: Whether the record is a success or error., defaults to None
        :type successful: bool, optional
        :param time_to_acknowledge_acceptance: The length of the time-out period, in the format *CCYYMMDDThhmmss.sss*, for acknowledging acceptance of a message. For a RosettaNet 2.0 interchange, the value is N/A., defaults to None
        :type time_to_acknowledge_acceptance: str, optional
        :param time_to_acknowledge_receipt: The length of the time-out period, in the format *CCYYMMDDThhmmss.sss*, for acknowledging receipt of a message. For a RosettaNet 2.0 interchange, the value is N/A., defaults to None
        :type time_to_acknowledge_receipt: str, optional
        :param time_to_perform: The maximum length of the time period, in the format *CCYYMMDDThhmmss.sss*, that an initiating business activity waits for a responding activity to process a document. For a RosettaNet 2.0 interchange, the value is N/A., defaults to None
        :type time_to_perform: str, optional
        :param to_global_business_service_code: The code identifying the receiving trading partner’s business service network component., defaults to None
        :type to_global_business_service_code: str, optional
        :param to_global_partner_role_classification_code: The code identifying the role the receiving trading partner plays in the PIP., defaults to None
        :type to_global_partner_role_classification_code: str, optional
        :param transaction_instance_identifier: The unique identifier for the transaction instance., defaults to None
        :type transaction_instance_identifier: str, optional
        """
        if pip_code is not SENTINEL:
            self.pip_code = pip_code
        if pip_version is not SENTINEL:
            self.pip_version = pip_version
        self.account = account
        if ack_report is not SENTINEL:
            self.ack_report = ack_report
        if ack_status is not SENTINEL:
            self.ack_status = ack_status
        if action_instance_identifier is not SENTINEL:
            self.action_instance_identifier = action_instance_identifier
        self.action_type = action_type
        self.atom_id = atom_id
        if attempt_count is not SENTINEL:
            self.attempt_count = attempt_count
        if business_activity_identifier is not SENTINEL:
            self.business_activity_identifier = business_activity_identifier
        self.connector_name = connector_name
        self.connector_type = connector_type
        self.custom_fields = self._define_object(custom_fields, CustomFields)
        self.date_processed = date_processed
        if date_time is not SENTINEL:
            self.date_time = date_time
        if document_index is not SENTINEL:
            self.document_index = document_index
        self.error_message = error_message
        self.execution_id = execution_id
        if framework_version is not SENTINEL:
            self.framework_version = framework_version
        if from_global_business_service_code is not SENTINEL:
            self.from_global_business_service_code = from_global_business_service_code
        if from_global_partner_role_classification_code is not SENTINEL:
            self.from_global_partner_role_classification_code = (
                from_global_partner_role_classification_code
            )
        if global_business_action_code is not SENTINEL:
            self.global_business_action_code = global_business_action_code
        if global_document_function_code is not SENTINEL:
            self.global_document_function_code = global_document_function_code
        if global_process_code is not SENTINEL:
            self.global_process_code = global_process_code
        if global_usage_code is not SENTINEL:
            self.global_usage_code = global_usage_code
        self.id_ = id_
        if in_response_to_global_business_action_code is not SENTINEL:
            self.in_response_to_global_business_action_code = (
                in_response_to_global_business_action_code
            )
        if in_response_to_instance_identifier is not SENTINEL:
            self.in_response_to_instance_identifier = in_response_to_instance_identifier
        if is_secure_transport_required is not SENTINEL:
            self.is_secure_transport_required = is_secure_transport_required
        if known_initiating_partner_id is not SENTINEL:
            self.known_initiating_partner_id = known_initiating_partner_id
        self.operation_name = operation_name
        if outbound_validation_report is not SENTINEL:
            self.outbound_validation_report = outbound_validation_report
        if outbound_validation_status is not SENTINEL:
            self.outbound_validation_status = outbound_validation_status
        if process_instance_identifier is not SENTINEL:
            self.process_instance_identifier = process_instance_identifier
        if receiver_id is not SENTINEL:
            self.receiver_id = receiver_id
        if sender_id is not SENTINEL:
            self.sender_id = sender_id
        if size is not SENTINEL:
            self.size = size
        if successful is not SENTINEL:
            self.successful = successful
        if time_to_acknowledge_acceptance is not SENTINEL:
            self.time_to_acknowledge_acceptance = time_to_acknowledge_acceptance
        if time_to_acknowledge_receipt is not SENTINEL:
            self.time_to_acknowledge_receipt = time_to_acknowledge_receipt
        if time_to_perform is not SENTINEL:
            self.time_to_perform = time_to_perform
        if to_global_business_service_code is not SENTINEL:
            self.to_global_business_service_code = to_global_business_service_code
        if to_global_partner_role_classification_code is not SENTINEL:
            self.to_global_partner_role_classification_code = (
                to_global_partner_role_classification_code
            )
        if transaction_instance_identifier is not SENTINEL:
            self.transaction_instance_identifier = transaction_instance_identifier
        self._kwargs = kwargs




from typing import Awaitable, Union
from .utils.to_async import to_async
from ..integration_pack_instance import IntegrationPackInstanceService
from ...models import (
    IntegrationPackInstance,
    IntegrationPackInstanceBulkResponse,
    IntegrationPackInstanceBulkRequest,
    IntegrationPackInstanceQueryResponse,
    IntegrationPackInstanceQueryConfig,
)


class IntegrationPackInstanceServiceAsync(IntegrationPackInstanceService):
    """
    Async Wrapper for IntegrationPackInstanceServiceAsync
    """

    def create_integration_pack_instance(
        self, request_body: IntegrationPackInstance = None
    ) -> Awaitable[Union[IntegrationPackInstance, str]]:
        return to_async(super().create_integration_pack_instance)(request_body)

    def get_integration_pack_instance(
        self, id_: str
    ) -> Awaitable[Union[IntegrationPackInstance, str]]:
        return to_async(super().get_integration_pack_instance)(id_)

    def delete_integration_pack_instance(self, id_: str) -> Awaitable[None]:
        return to_async(super().delete_integration_pack_instance)(id_)

    def bulk_integration_pack_instance(
        self, request_body: IntegrationPackInstanceBulkRequest = None
    ) -> Awaitable[Union[IntegrationPackInstanceBulkResponse, str]]:
        return to_async(super().bulk_integration_pack_instance)(request_body)

    def query_integration_pack_instance(
        self, request_body: IntegrationPackInstanceQueryConfig = None
    ) -> Awaitable[Union[IntegrationPackInstanceQueryResponse, str]]:
        return to_async(super().query_integration_pack_instance)(request_body)

    def query_more_integration_pack_instance(
        self, request_body: str
    ) -> Awaitable[Union[IntegrationPackInstanceQueryResponse, str]]:
        return to_async(super().query_more_integration_pack_instance)(request_body)
